@@ -50,10 +50,12 @@
 #include "../Mapping/OneJumpSubstitutionCount.h"
 #include "../OptimizationTools.h"
 #include "../Tree.h"
-#include "../Io/Newick.h"
-#include "../Io/NexusIoTree.h"
-#include "../Io/Nhx.h"
+#include "../Io/BppOTreeReaderFormat.h"
+#include "../Io/BppOMultiTreeReaderFormat.h"
+#include "../Io/BppOTreeWriterFormat.h"
+#include "../Io/BppOMultiTreeWriterFormat.h"
 #include "../Io/BppOSubstitutionModelFormat.h"
+#include "../Io/BppOTransitionModelFormat.h"
 #include "../Io/BppOFrequenciesSetFormat.h"
 #include "../Io/BppORateDistributionFormat.h"
 
@@ -104,20 +106,14 @@ Tree* PhylogeneticsApplicationTools::getTree(
   string format = ApplicationTools::getStringParameter(prefix + "tree.format", params, "Newick", suffix, suffixIsOptional, warn);
   string treeFilePath = ApplicationTools::getAFilePath(prefix + "tree.file", params, true, true, suffix, suffixIsOptional, "none", warn);
 
-  ITree* treeReader;
-  if (format == "Newick")
-    treeReader = new Newick(true);
-  else if (format == "Nexus")
-    treeReader = new NexusIOTree();
-  else if (format == "NHX")
-    treeReader = new Nhx();
-  else
-    throw Exception("Unknow format for tree reading: " + format);
-  Tree* tree = treeReader->read(treeFilePath);
-  delete treeReader;
-
+  BppOTreeReaderFormat bppoReader(warn);
+  unique_ptr<ITree> iTree(bppoReader.read(format));
   if (verbose)
-    ApplicationTools::displayResult("Tree file", treeFilePath);
+  {
+    ApplicationTools::displayResult("Input tree file " + suffix, treeFilePath);
+    ApplicationTools::displayResult("Input tree format " + suffix, iTree->getFormatName());
+  }
+  Tree* tree = iTree->read(treeFilePath);
   return tree;
 }
 
@@ -134,22 +130,18 @@ vector<Tree*> PhylogeneticsApplicationTools::getTrees(
   string format = ApplicationTools::getStringParameter(prefix + "trees.format", params, "Newick", suffix, suffixIsOptional, warn);
   string treeFilePath = ApplicationTools::getAFilePath(prefix + "trees.file", params, true, true, suffix, suffixIsOptional, "none", warn);
 
-  IMultiTree* treeReader;
-  if (format == "Newick")
-    treeReader = new Newick(true);
-  else if (format == "Nexus")
-    treeReader = new NexusIOTree();
-  else if (format == "NHX")
-    treeReader = new Nhx();
-  else
-    throw Exception("Unknow format for tree reading: " + format);
+  BppOMultiTreeReaderFormat bppoReader(warn);
+  unique_ptr<IMultiTree> iTrees(bppoReader.read(format));
+  if (verbose)
+  {
+    ApplicationTools::displayResult("Input trees file " + suffix, treeFilePath);
+    ApplicationTools::displayResult("Input trees format " + suffix, iTrees->getFormatName());
+  }
   vector<Tree*> trees;
-  treeReader->read(treeFilePath, trees);
-  delete treeReader;
+  iTrees->read(treeFilePath, trees);
 
   if (verbose)
   {
-    ApplicationTools::displayResult("Tree file", treeFilePath);
     ApplicationTools::displayResult("Number of trees in file", trees.size());
   }
   return trees;
@@ -175,12 +167,14 @@ SubstitutionModel* PhylogeneticsApplicationTools::getSubstitutionModel(
   BppOSubstitutionModelFormat bIO(BppOSubstitutionModelFormat::ALL, true, true, true, verbose, warn + 1);
   string modelDescription;
   const CodonAlphabet* ca = dynamic_cast<const CodonAlphabet*>(alphabet);
-  if (ca) {
+  if (ca)
+  {
     modelDescription = ApplicationTools::getStringParameter("model", params, "CodonRate(model=JC69)", suffix, suffixIsOptional, warn);
     if (!gCode)
       throw Exception("PhylogeneticsApplicationTools::getSubstitutionModel(): a GeneticCode instance is required for instanciating a codon model.");
     bIO.setGeneticCode(gCode);
-  } else if (AlphabetTools::isWordAlphabet(alphabet))
+  }
+  else if (AlphabetTools::isWordAlphabet(alphabet))
     modelDescription = ApplicationTools::getStringParameter("model", params, "Word(model=JC69)", suffix, suffixIsOptional, warn);
   else
     modelDescription = ApplicationTools::getStringParameter("model", params, "JC69", suffix, suffixIsOptional, warn);
@@ -189,18 +183,46 @@ SubstitutionModel* PhylogeneticsApplicationTools::getSubstitutionModel(
   return model;
 }
 
+TransitionModel* PhylogeneticsApplicationTools::getTransitionModel(
+  const Alphabet* alphabet,
+  const GeneticCode* gCode,
+  const SiteContainer* data,
+  std::map<std::string, std::string>& params,
+  const string& suffix,
+  bool suffixIsOptional,
+  bool verbose,
+  int warn) throw (Exception)
+{
+  BppOTransitionModelFormat bIO(BppOSubstitutionModelFormat::ALL, true, true, true, verbose, warn + 1);
+  string modelDescription;
+  const CodonAlphabet* ca = dynamic_cast<const CodonAlphabet*>(alphabet);
+  if (ca)
+  {
+    modelDescription = ApplicationTools::getStringParameter("model", params, "CodonRate(model=JC69)", suffix, suffixIsOptional, warn);
+    if (!gCode)
+      throw Exception("PhylogeneticsApplicationTools::getSubstitutionModel(): a GeneticCode instance is required for instanciating a codon model.");
+    bIO.setGeneticCode(gCode);
+  }
+  else if (AlphabetTools::isWordAlphabet(alphabet))
+    modelDescription = ApplicationTools::getStringParameter("model", params, "Word(model=JC69)", suffix, suffixIsOptional, warn);
+  else
+    modelDescription = ApplicationTools::getStringParameter("model", params, "JC69", suffix, suffixIsOptional, warn);
+
+  TransitionModel* model = bIO.readTransitionModel(alphabet, modelDescription, data, true);
+  return model;
+}
+
 /******************************************************************************/
 
 void PhylogeneticsApplicationTools::setSubstitutionModelParametersInitialValuesWithAliases(
-  SubstitutionModel& model,
+  TransitionModel& model,
   std::map<std::string, std::string>& unparsedParameterValues,
   size_t modelNumber,
   const SiteContainer* data,
-  std::map<std::string, double>& existingParams,
   std::map<std::string, std::string>& sharedParams,
   bool verbose) throw (Exception)
 {
-  string initFreqs = ApplicationTools::getStringParameter(model.getNamespace() + "initFreqs", unparsedParameterValues, "", "", true, false);
+  string initFreqs = ApplicationTools::getStringParameter(model.getNamespace() + "initFreqs", unparsedParameterValues, "", "", true, 2);
 
   if (verbose)
     ApplicationTools::displayResult("Frequencies Initialization for model", (initFreqs == "") ? "None" : initFreqs);
@@ -231,7 +253,6 @@ void PhylogeneticsApplicationTools::setSubstitutionModelParametersInitialValuesW
   }
 
 
-  
   ParameterList pl = model.getIndependentParameters();
   for (size_t i = 0; i < pl.size(); ++i)
   {
@@ -248,31 +269,27 @@ void PhylogeneticsApplicationTools::setSubstitutionModelParametersInitialValuesW
     bool test1 = (initFreqs == "");
     bool test2 = (model.getParameterNameWithoutNamespace(pName).substr(posp + 1, 5) != "theta");
     bool test3 = (unparsedParameterValues.find(pName) != unparsedParameterValues.end());
+
     if (test1 || test2 || test3)
     {
       if (!test1 && !test2 && test3)
         ApplicationTools::displayWarning("Warning, initFreqs argument is set and a value is set for parameter " + pName);
-      value = ApplicationTools::getStringParameter(pName, unparsedParameterValues, TextTools::toString(pl[i].getValue()));
-      if (value.rfind("_")!=string::npos)
-      {
-        if (existingParams.find(value) != existingParams.end())
-          {
-            pl[i].setValue(existingParams[value]);
-            sharedParams[pl[i].getName()+"_"+TextTools::toString(modelNumber)]=value;
-          }
-        else
-          throw Exception("Error, unknown parameter " + value);
-      }
-      else
-        pl[i].setValue(TextTools::toDouble(value));
-    }
 
-    existingParams[pName+"_"+TextTools::toString(modelNumber)] = pl[i].getValue();
-    
-    if (verbose)
-      ApplicationTools::displayResult("Parameter found", pName + +"_"+TextTools::toString(modelNumber) + "=" + TextTools::toString(pl[i].getValue()));
+      value = ApplicationTools::getStringParameter(pName, unparsedParameterValues, TextTools::toString(pl[i].getValue()));
+
+      try
+      {
+        pl[i].setValue(TextTools::toDouble(value));
+        if (verbose)
+          ApplicationTools::displayResult("Parameter found", pName + +"_" + TextTools::toString(modelNumber) + "=" + TextTools::toString(pl[i].getValue()));
+      }
+      catch (Exception& e)
+      {
+        sharedParams[pl[i].getName() + "_" + TextTools::toString(modelNumber)] = value;
+      }
+    }
   }
-  
+
   model.matchParametersValues(pl);
 }
 
@@ -288,6 +305,7 @@ FrequenciesSet* PhylogeneticsApplicationTools::getRootFrequenciesSet(
   const GeneticCode* gCode,
   const SiteContainer* data,
   std::map<std::string, std::string>& params,
+  std::map<std::string, std::string>& sharedparams,
   const std::vector<double>& rateFreqs,
   const std::string& suffix,
   bool suffixIsOptional,
@@ -301,7 +319,17 @@ FrequenciesSet* PhylogeneticsApplicationTools::getRootFrequenciesSet(
   }
   else
   {
-    FrequenciesSet* freq = getFrequenciesSet(alphabet, gCode, freqDescription, data, rateFreqs, verbose, warn + 1);
+    map<string, string> unparams;
+
+    FrequenciesSet* freq = getFrequenciesSet(alphabet, gCode, freqDescription, data, unparams, rateFreqs, verbose, warn + 1);
+    freq->setNamespace("root." + freq->getNamespace());
+
+    map<string, string>::iterator it;
+    for (it = unparams.begin(); it != unparams.end(); it++)
+    {
+      sharedparams["root." + it->first] = it->second;
+    }
+
     if (verbose)
       ApplicationTools::displayResult("Root frequencies ", freq->getName());
     return freq;
@@ -315,19 +343,25 @@ FrequenciesSet* PhylogeneticsApplicationTools::getFrequenciesSet(
   const GeneticCode* gCode,
   const std::string& freqDescription,
   const SiteContainer* data,
+  std::map<std::string, std::string>& sharedparams,
   const std::vector<double>& rateFreqs,
   bool verbose,
   int warn) throw (Exception)
 {
   map<string, string> unparsedParameterValues;
   BppOFrequenciesSetFormat bIO(BppOFrequenciesSetFormat::ALL, verbose, warn);
-  if (AlphabetTools::isCodonAlphabet(alphabet)) {
+  if (AlphabetTools::isCodonAlphabet(alphabet))
+  {
     if (!gCode)
       throw Exception("PhylogeneticsApplicationTools::getFrequenciesSet(): a GeneticCode instance is required for instanciating a codon frequencies set.");
     bIO.setGeneticCode(gCode);
   }
-  auto_ptr<FrequenciesSet> pFS(bIO.read(alphabet, freqDescription, data, true));
-  
+  unique_ptr<FrequenciesSet> pFS(bIO.read(alphabet, freqDescription, data, true));
+
+  std::map<std::string, std::string> unparsedparam = bIO.getUnparsedArguments();
+
+  sharedparams.insert(unparsedparam.begin(), unparsedparam.end());
+
   // /////// To be changed for input normalization
   if (rateFreqs.size() > 0)
   {
@@ -359,16 +393,16 @@ SubstitutionModelSet* PhylogeneticsApplicationTools::getSubstitutionModelSet(
   if (nbModels == 0)
     throw Exception("The number of models can't be 0 !");
 
-  bool nomix = true;
-  for (size_t i = 0; nomix &(i < nbModels); i++)
-  {
-    string prefix = "model" + TextTools::toString(i + 1);
-    string modelDesc;
-    modelDesc = ApplicationTools::getStringParameter(prefix, params, "", suffix, suffixIsOptional, warn);
+  // bool nomix = true;
+  // for (size_t i = 0; nomix &(i < nbModels); i++)
+  // {
+  //   string prefix = "model" + TextTools::toString(i + 1);
+  //   string modelDesc;
+  //   modelDesc = ApplicationTools::getStringParameter(prefix, params, "", suffix, suffixIsOptional, warn);
 
-    if (modelDesc.find("Mixed") != string::npos)
-      nomix = false;
-  }
+  //   if (modelDesc.find("Mixed") != string::npos)
+  //     nomix = false;
+  // }
 
   SubstitutionModelSet* modelSet, * modelSet1 = 0;
   modelSet1 = new SubstitutionModelSet(alphabet);
@@ -408,25 +442,26 @@ void PhylogeneticsApplicationTools::setSubstitutionModelSet(
   if (verbose)
     ApplicationTools::displayResult("Number of distinct models", TextTools::toString(nbModels));
 
-  BppOSubstitutionModelFormat bIO(BppOSubstitutionModelFormat::ALL, true, true, true, false, warn);
+  BppOTransitionModelFormat bIO(BppOSubstitutionModelFormat::ALL, true, true, true, false, warn);
 
   // ///////////////////////////////////////////
   // Build a new model set object:
 
   vector<double> rateFreqs;
   string tmpDesc;
-  if (AlphabetTools::isCodonAlphabet(alphabet)) {
+  if (AlphabetTools::isCodonAlphabet(alphabet))
+  {
     if (!gCode)
       throw Exception("PhylogeneticsApplicationTools::setSubstitutionModelSet(): a GeneticCode instance is required for instanciating a codon model.");
     bIO.setGeneticCode(gCode);
     tmpDesc = ApplicationTools::getStringParameter("model1", params, "CodonRate(model=JC69)", suffix, suffixIsOptional, warn);
-  } else if (AlphabetTools::isWordAlphabet(alphabet))
+  }
+  else if (AlphabetTools::isWordAlphabet(alphabet))
     tmpDesc = ApplicationTools::getStringParameter("model1", params, "Word(model=JC69)", suffix, suffixIsOptional, warn);
   else
     tmpDesc = ApplicationTools::getStringParameter("model1", params, "JC69", suffix, suffixIsOptional, warn);
 
-  auto_ptr<SubstitutionModel> tmp(bIO.read(alphabet, tmpDesc, data, false));
-  //  map<string, string> tmpUnparsedParameterValues(bIO.getUnparsedArguments());
+  unique_ptr<TransitionModel> tmp(bIO.readTransitionModel(alphabet, tmpDesc, data, false));
 
   if (tmp->getNumberOfStates() != alphabet->getSize())
   {
@@ -438,11 +473,13 @@ void PhylogeneticsApplicationTools::setSubstitutionModelSet(
   // ////////////////////////////////////
   // Deal with root frequencies
 
+  map<string, string> unparsedParameters;
+
   bool stationarity = ApplicationTools::getBooleanParameter("nonhomogeneous.stationarity", params, false, "", true, warn);
   FrequenciesSet* rootFrequencies = 0;
   if (!stationarity)
   {
-    rootFrequencies = getRootFrequenciesSet(alphabet, gCode, data, params, rateFreqs, suffix, suffixIsOptional, verbose);
+    rootFrequencies = getRootFrequenciesSet(alphabet, gCode, data, params, unparsedParameters, rateFreqs, suffix, suffixIsOptional, verbose);
     stationarity = !rootFrequencies;
     string freqDescription = ApplicationTools::getStringParameter("nonhomogeneous.root_freq", params, "", suffix, suffixIsOptional, warn);
     if (freqDescription.substr(0, 10) == "MVAprotein")
@@ -453,17 +490,17 @@ void PhylogeneticsApplicationTools::setSubstitutionModelSet(
         throw Exception("The MVAprotein frequencies set at the root can only be used if a Coala model is used on branches.");
     }
   }
+
   ApplicationTools::displayBooleanResult("Stationarity assumed", stationarity);
 
   if (!stationarity)
     modelSet.setRootFrequencies(rootFrequencies);
 
+
   // //////////////////////////////////////
   // Now parse all models:
 
   bIO.setVerbose(true);
-  
-  map<string, double> existingParameters;
 
   for (size_t i = 0; i < nbModels; i++)
   {
@@ -476,31 +513,27 @@ void PhylogeneticsApplicationTools::setSubstitutionModelSet(
     else
       modelDesc = ApplicationTools::getStringParameter(prefix, params, "JC69", suffix, suffixIsOptional, warn);
 
-    auto_ptr<SubstitutionModel> model(bIO.read(alphabet, modelDesc, data, false));
-    map<string, string> unparsedParameterValues(bIO.getUnparsedArguments());
+    unique_ptr<TransitionModel> model(bIO.readTransitionModel(alphabet, modelDesc, data, false));
 
+    map<string, string> unparsedModelParameters = bIO.getUnparsedArguments();
     map<string, string> sharedParameters;
+
     setSubstitutionModelParametersInitialValuesWithAliases(
       *model,
-      unparsedParameterValues, i+1, data,
-      existingParameters, sharedParameters,
+      unparsedModelParameters, i + 1, data,
+      sharedParameters,
       verbose);
 
+    unparsedParameters.insert(sharedParameters.begin(), sharedParameters.end());
+
     vector<int> nodesId = ApplicationTools::getVectorParameter<int>(prefix + ".nodes_id", params, ',', ':', TextTools::toString(i), suffix, suffixIsOptional, warn);
 
     if (verbose)
       ApplicationTools::displayResult("Model" + TextTools::toString(i + 1) + " is associated to", TextTools::toString(nodesId.size()) + " node(s).");
 
-    modelSet.addModel(model.get(), nodesId);
-
-    // Now set shared parameters:
-    map<string, string>::const_iterator it;
-    for (it=sharedParameters.begin(); it!=sharedParameters.end(); it++)
-      modelSet.aliasParameters(it->second, it->first);
-    
-    model.release();
+    modelSet.addModel(model.release(), nodesId);
   }
-  
+
   // Finally check parameter aliasing:
   string aliasDesc = ApplicationTools::getStringParameter("nonhomogeneous.alias", params, "", suffix, suffixIsOptional, warn);
   StringTokenizer st(aliasDesc, ",");
@@ -509,12 +542,13 @@ void PhylogeneticsApplicationTools::setSubstitutionModelSet(
     string alias = st.nextToken();
     string::size_type index = alias.find("->");
     if (index == string::npos)
-      throw Exception("PhylogeneticsApplicationTools::getSubstitutionModelSet. Bad alias syntax, should contain `->' symbol: " + alias);
-    string p1 = alias.substr(0, index);
-    string p2 = alias.substr(index + 2);
-    ApplicationTools::displayResult("Parameter alias found", p1 + "->" + p2);
-    modelSet.aliasParameters(p1, p2);
+      throw Exception("PhylogeneticsApplicationTools::setSubstitutionModelSet. Bad alias syntax, should contain `->' symbol: " + alias);
+    unparsedParameters[alias.substr(0, index)] = alias.substr(index + 2);
   }
+
+  // alias unparsedParameters
+
+  modelSet.aliasParameters(unparsedParameters, verbose);
 }
 
 /******************************************************************************/
@@ -572,7 +606,7 @@ void PhylogeneticsApplicationTools::completeMixedSubstitutionModelSet(
       size_t num = TextTools::to<size_t>(submodel.substr(5, indexo - 5));
       string p2 = submodel.substr(indexo + 1, indexf - indexo - 1);
 
-      const MixedSubstitutionModel* pSM = dynamic_cast<const MixedSubstitutionModel*>(mixedModelSet.getModel(num - 1));
+      const MixedSubstitutionModel* pSM = dynamic_cast<const MixedSubstitutionModel*>(mixedModelSet.getSubstitutionModel(num - 1));
       if (!pSM)
         throw BadIntegerException("PhylogeneticsApplicationTools::setMixedSubstitutionModelSet: Wrong model for number", static_cast<int>(num - 1));
       Vint submodnb = pSM->getSubmodelNumbers(p2);
@@ -671,7 +705,7 @@ DiscreteDistribution* PhylogeneticsApplicationTools::getRateDistribution(
   KeyvalTools::parseProcedure(distDescription, distName, args);
 
   BppORateDistributionFormat bIO(true);
-  auto_ptr<DiscreteDistribution> rDist(bIO.read(distDescription, true));
+  unique_ptr<DiscreteDistribution> rDist(bIO.read(distDescription, true));
 
   if (verbose)
   {
@@ -751,7 +785,7 @@ throw (Exception)
   // Should I ignore some parameters?
   ParameterList parametersToEstimate = parameters;
   vector<string> parNames = parametersToEstimate.getParameterNames();
-  
+
   if (params.find("optimization.ignore_parameter") != params.end())
     throw Exception("optimization.ignore_parameter is deprecated, use optimization.ignore_parameters instead!");
   string paramListDesc = ApplicationTools::getStringParameter("optimization.ignore_parameters", params, "", suffix, suffixIsOptional, warn + 1);
@@ -782,25 +816,26 @@ throw (Exception)
           ApplicationTools::displayResult("Parameter ignored", string("Root frequencies"));
       }
       else if (param == "Model")
+      {
+        vector<string> vs;
+        vector<string> vs1 = tl->getSubstitutionModelParameters().getParameterNames();
+        NonHomogeneousTreeLikelihood* nhtl = dynamic_cast<NonHomogeneousTreeLikelihood*>(tl);
+        if (nhtl != NULL)
         {
-          vector<string> vs;
-          vector<string> vs1 = tl->getSubstitutionModelParameters().getParameterNames();
-          NonHomogeneousTreeLikelihood* nhtl = dynamic_cast<NonHomogeneousTreeLikelihood*>(tl);
-          if (nhtl!=NULL){
-            vector<string> vs2 = nhtl->getRootFrequenciesParameters().getParameterNames();
-            VectorTools::diff(vs1,vs2,vs);
-            }
-          else
-            vs=vs1;
-
-          parametersToEstimate.deleteParameters(vs);
-          if (verbose)
-            ApplicationTools::displayResult("Parameter ignored", string("Model"));          
+          vector<string> vs2 = nhtl->getRootFrequenciesParameters().getParameterNames();
+          VectorTools::diff(vs1, vs2, vs);
         }
+        else
+          vs = vs1;
+
+        parametersToEstimate.deleteParameters(vs);
+        if (verbose)
+          ApplicationTools::displayResult("Parameter ignored", string("Model"));
+      }
       else if (param.find("*") != string::npos)
       {
-        vector<string> vs=ApplicationTools::matchingParameters(param,parNames);
-        
+        vector<string> vs = ApplicationTools::matchingParameters(param, parNames);
+
         for (vector<string>::iterator it = vs.begin(); it != vs.end(); it++)
         {
           parametersToEstimate.deleteParameter(*it);
@@ -823,14 +858,14 @@ throw (Exception)
 
   // Should I constrain some parameters?
   vector<string> parToEstNames = parametersToEstimate.getParameterNames();
-  
+
   if (params.find("optimization.constrain_parameter") != params.end())
     throw Exception("optimization.constrain_parameter is deprecated, use optimization.constrain_parameters instead!");
   paramListDesc = ApplicationTools::getStringParameter("optimization.constrain_parameters", params, "", suffix, suffixIsOptional, warn + 1);
 
-  string constraint="";
-  string pc, param="";
-  
+  string constraint = "";
+  string pc, param = "";
+
   StringTokenizer st2(paramListDesc, ",");
   while (st2.hasMoreToken())
   {
@@ -843,12 +878,13 @@ throw (Exception)
       param = pc.substr(0, index);
       constraint = pc.substr(index + 1);
       IntervalConstraint ic(constraint);
-      
+
       vector<string> parNames2;
-      
+
       if (param == "BrLen")
         parNames2  = tl->getBranchLengthsParameters().getParameterNames();
-      else if (param == "Ancient"){
+      else if (param == "Ancient")
+      {
         NonHomogeneousTreeLikelihood* nhtl = dynamic_cast<NonHomogeneousTreeLikelihood*>(tl);
         if (!nhtl)
           ApplicationTools::displayWarning("The 'Ancient' parameters do not exist in homogeneous models, and will be ignored.");
@@ -862,23 +898,25 @@ throw (Exception)
       {
         vector<string> vs1 = tl->getSubstitutionModelParameters().getParameterNames();
         NonHomogeneousTreeLikelihood* nhtl = dynamic_cast<NonHomogeneousTreeLikelihood*>(tl);
-        if (nhtl!=NULL){
+        if (nhtl != NULL)
+        {
           vector<string> vs2 = nhtl->getRootFrequenciesParameters().getParameterNames();
-          VectorTools::diff(vs1,vs2,parNames2);
+          VectorTools::diff(vs1, vs2, parNames2);
         }
         else
-          parNames2=vs1;
+          parNames2 = vs1;
       }
       else if (param.find("*") != string::npos)
-        parNames2=ApplicationTools::matchingParameters(param,parToEstNames);
+        parNames2 = ApplicationTools::matchingParameters(param, parToEstNames);
       else
         parNames2.push_back(param);
 
-      
-      for (size_t i=0; i<parNames2.size(); i++)
+
+      for (size_t i = 0; i < parNames2.size(); i++)
       {
-        Parameter& par=parametersToEstimate.getParameter(parNames2[i]);
-        if (par.hasConstraint()){
+        Parameter& par = parametersToEstimate.getParameter(parNames2[i]);
+        if (par.hasConstraint())
+        {
           par.setConstraint(ic & (*par.getConstraint()), true);
           if (par.getConstraint()->isEmpty())
             throw Exception("Empty interval for parameter " + parNames[i] + par.getConstraint()->getDescription());
@@ -900,10 +938,10 @@ throw (Exception)
     }
   }
 
-  
-  ///////
-  /// optimization options
-  
+
+  // /////
+  // / optimization options
+
   unsigned int nbEvalMax = ApplicationTools::getParameter<unsigned int>("optimization.max_number_f_eval", params, 1000000, suffix, suffixIsOptional, warn + 1);
   if (verbose)
     ApplicationTools::displayResult("Max # ML evaluations", TextTools::toString(nbEvalMax));
@@ -913,7 +951,7 @@ throw (Exception)
     ApplicationTools::displayResult("Tolerance", TextTools::toString(tolerance));
 
   // Backing up or restoring?
-  auto_ptr<BackupListener> backupListener;
+  unique_ptr<BackupListener> backupListener;
   string backupFile = ApplicationTools::getAFilePath("optimization.backup.file", params, false, false, suffix, suffixIsOptional, "none", warn + 1);
   if (backupFile != "none")
   {
@@ -946,7 +984,7 @@ throw (Exception)
       bck.close();
       tl->setParameters(pl);
       if (abs(tl->getValue() - fval) > 0.000001)
-        throw Exception("Incorrect likelihood value after restoring, from backup file. Remove backup file and start from scratch :s");
+        ApplicationTools::displayWarning("Warning, incorrect likelihood value after restoring from backup file.");
       ApplicationTools::displayResult("Restoring log-likelihood", -fval);
     }
   }
@@ -1100,7 +1138,8 @@ throw (Exception)
     ApplicationTools::displayResult("Performed", TextTools::toString(n) + " function evaluations.");
   if (backupFile != "none")
   {
-    remove(backupFile.c_str());
+    string bf=backupFile+".def";
+    rename(backupFile.c_str(),bf.c_str());
   }
   return tl;
 }
@@ -1215,7 +1254,7 @@ throw (Exception)
     ApplicationTools::displayResult("Algorithm used for derivable parameters", order);
 
   // Backing up or restoring?
-  auto_ptr<BackupListener> backupListener;
+  unique_ptr<BackupListener> backupListener;
   string backupFile = ApplicationTools::getAFilePath("optimization.backup.file", params, false, false, suffix, suffixIsOptional, "none", warn + 1);
   if (backupFile != "none")
   {
@@ -1324,7 +1363,8 @@ throw (Exception)
     ApplicationTools::displayResult("Performed", TextTools::toString(n) + " function evaluations.");
   if (backupFile != "none")
   {
-    remove(backupFile.c_str());
+    string bf=backupFile+".def";
+    rename(backupFile.c_str(),bf.c_str());
   }
 }
 
@@ -1359,21 +1399,17 @@ void PhylogeneticsApplicationTools::writeTree(
   int warn) throw (Exception)
 {
   string format = ApplicationTools::getStringParameter(prefix + "tree.format", params, "Newick", suffix, suffixIsOptional, warn);
-  string file = ApplicationTools::getAFilePath(prefix + "tree.file", params, true, false, suffix, suffixIsOptional, "none", warn);
-  OTree* treeWriter;
-  if (format == "Newick")
-    treeWriter = new Newick();
-  else if (format == "Nexus")
-    treeWriter = new NexusIOTree();
-  else if (format == "NHX")
-    treeWriter = new Nhx(false);
-  else
-    throw Exception("Unknown format for tree writing: " + format);
-  if (!checkOnly)
-    treeWriter->write(tree, file, true);
-  delete treeWriter;
+  string file = ApplicationTools::getAFilePath(prefix + "tree.file", params, false, false, suffix, suffixIsOptional, "none", warn);
+ 
+  BppOTreeWriterFormat bppoWriter(warn);
+  unique_ptr<OTree> oTree(bppoWriter.read(format));
   if (verbose)
-    ApplicationTools::displayResult("Wrote tree to file ", file);
+  {
+    ApplicationTools::displayResult("Output tree file " + suffix, file);
+    ApplicationTools::displayResult("Output tree format " + suffix, oTree->getFormatName());
+  }
+  if (!checkOnly && file != "none")
+    oTree->write(tree, file, true);  
 }
 
 /******************************************************************************/
@@ -1390,25 +1426,22 @@ void PhylogeneticsApplicationTools::writeTrees(
 {
   string format = ApplicationTools::getStringParameter(prefix + "trees.format", params, "Newick", suffix, suffixIsOptional, warn);
   string file = ApplicationTools::getAFilePath(prefix + "trees.file", params, true, false, suffix, suffixIsOptional, "none", warn);
-  OMultiTree* treeWriter;
-  if (format == "Newick")
-    treeWriter = new Newick();
-  else if (format == "Nexus")
-    treeWriter = new NexusIOTree();
-  else if (format == "NHX")
-    treeWriter = new Nhx();
-  else
-    throw Exception("Unknow format for tree writing: " + format);
-  if (!checkOnly)
-    treeWriter->write(trees, file, true);
-  delete treeWriter;
+
+  BppOMultiTreeWriterFormat bppoWriter(warn);
+  unique_ptr<OMultiTree> oTrees(bppoWriter.read(format));
   if (verbose)
-    ApplicationTools::displayResult("Wrote trees to file ", file);
+  {
+    ApplicationTools::displayResult("Output trees file " + suffix, file);
+    ApplicationTools::displayResult("Output trees format " + suffix, oTrees->getFormatName());
+  }
+  if (!checkOnly && file != "none")
+    oTrees->write(trees, file, true);
+  
 }
 
 /******************************************************************************/
 
-void PhylogeneticsApplicationTools::printParameters(const SubstitutionModel* model, OutputStream& out, int warn)
+void PhylogeneticsApplicationTools::printParameters(const TransitionModel* model, OutputStream& out, int warn, bool withAlias)
 {
   out << "model=";
   map<string, string> globalAliases;
@@ -1420,11 +1453,14 @@ void PhylogeneticsApplicationTools::printParameters(const SubstitutionModel* mod
 
 /******************************************************************************/
 
-void PhylogeneticsApplicationTools::printParameters(const SubstitutionModelSet* modelSet, OutputStream& out, int warn)
+void PhylogeneticsApplicationTools::printParameters(const SubstitutionModelSet* modelSet, OutputStream& out, int warn, bool withAlias)
 {
   (out << "nonhomogeneous=general").endLine();
   (out << "nonhomogeneous.number_of_models=" << modelSet->getNumberOfModels()).endLine();
 
+  if (modelSet->isStationary())
+    (out << "nonhomogeneous.stationarity = yes");
+    
   // Get the parameter links:
   map< size_t, vector<string> > modelLinks; // for each model index, stores the list of global parameters.
   map< string, set<size_t> > parameterLinks; // for each parameter name, stores the list of model indices, wich should be sorted.
@@ -1433,26 +1469,30 @@ void PhylogeneticsApplicationTools::printParameters(const SubstitutionModelSet*
   // Loop over all models:
   for (size_t i = 0; i < modelSet->getNumberOfModels(); i++)
   {
-    const SubstitutionModel* model = modelSet->getModel(i);
+    const TransitionModel* model = modelSet->getTransitionModel(i);
 
-    // First get the aliases for this model:
     map<string, string> aliases;
 
-    ParameterList pl=model->getParameters();
+    // First get the aliases for this model:
 
-    for (size_t np = 0 ; np< pl.size() ; np++)
+    if (withAlias)
+    {
+      ParameterList pl = model->getParameters();
+
+      for (size_t np = 0; np < pl.size(); np++)
       {
         string nfrom = modelSet->getFrom(pl[np].getName() + "_" + TextTools::toString(i + 1));
         if (nfrom != "")
           aliases[pl[np].getName()] = nfrom;
       }
+    }
 
     // Now print it:
     writtenNames.clear();
     out.endLine() << "model" << (i + 1) << "=";
     BppOSubstitutionModelFormat bIOsm(BppOSubstitutionModelFormat::ALL, true, true, true, false, warn);
-    map<string, string>::iterator it;
     bIOsm.write(*model, out, aliases, writtenNames);
+
     out.endLine();
     vector<int> ids = modelSet->getNodesWithModel(i);
     out << "model" << (i + 1) << ".nodes_id=" << ids[0];
@@ -1463,18 +1503,41 @@ void PhylogeneticsApplicationTools::printParameters(const SubstitutionModelSet*
     out.endLine();
   }
 
-  // Root frequencies:
-  out.endLine();
-  (out << "# Root frequencies:").endLine();
-  out << "nonhomogeneous.root_freq=";
+  // First get the aliases for this frequencies set
 
-  BppOFrequenciesSetFormat bIO(BppOFrequenciesSetFormat::ALL, false, warn);
-  bIO.write(modelSet->getRootFrequenciesSet(), out, writtenNames);
+  if (!modelSet->isStationary())
+  {
+    
+    const FrequenciesSet* pFS = modelSet->getRootFrequenciesSet();
+
+    ParameterList plf = pFS->getParameters();
+
+    map<string, string> aliases;
+    
+    if (withAlias)
+    {
+      for (size_t np = 0; np < plf.size(); np++)
+      {
+        string nfrom = modelSet->getFrom(plf[np].getName());
+        if (nfrom != "")
+          aliases[plf[np].getName()] = nfrom;
+      }
+    }
+    
+    // Root frequencies:
+    out.endLine();
+    (out << "# Root frequencies:").endLine();
+    out << "nonhomogeneous.root_freq=";
+    
+    BppOFrequenciesSetFormat bIO(BppOFrequenciesSetFormat::ALL, false, warn);
+    bIO.write(pFS, out, aliases, writtenNames);
+  }
+  
 }
 
 /******************************************************************************/
 
-void PhylogeneticsApplicationTools::printParameters(const DiscreteDistribution* rDist, OutputStream& out)
+void PhylogeneticsApplicationTools::printParameters(const DiscreteDistribution* rDist, OutputStream& out, bool withAlias)
 {
   out << "rate_distribution=";
   map<string, string> globalAliases;
@@ -1487,9 +1550,8 @@ void PhylogeneticsApplicationTools::printParameters(const DiscreteDistribution*
 }
 
 /************************
- * Substitution Mapping *
- ************************/
-
+* Substitution Mapping *
+************************/
 SubstitutionCount* PhylogeneticsApplicationTools::getSubstitutionCount(
   const Alphabet* alphabet,
   const SubstitutionModel* model,
@@ -1551,4 +1613,3 @@ SubstitutionCount* PhylogeneticsApplicationTools::getSubstitutionCount(
 }
 
 /******************************************************************************/
-
