@@ -120,12 +120,7 @@ class BipartitionList:
 
     virtual ~BipartitionList();
 
-#ifndef NO_VIRTUAL_COV
-    BipartitionList*
-#else
-    Clonable*
-#endif
-    clone() const { return new BipartitionList(*this); }
+    BipartitionList* clone() const { return new BipartitionList(*this); }
 
   public:
 
