@@ -53,9 +53,12 @@ knowledge of the CeCILL license and that you accept its terms.
 #include <Bpp/Numeric/Function/SimpleMultiDimensions.h>
 #include <Bpp/Numeric/Function/MetaOptimizer.h>
 
-// From SeqLib:
+// From bpp-seq:
 #include <Bpp/Seq/Container/SiteContainer.h>
 
+// From the STL:
+#include <memory>
+
 namespace bpp
 {
 
@@ -68,7 +71,7 @@ class TwoTreeLikelihood:
   private:
     SiteContainer* shrunkData_;
     std::vector<std::string> seqnames_;
-    SubstitutionModel* model_;
+    TransitionModel* model_;
     ParameterList brLenParameters_;
     
     mutable VVVdouble pxy_;
@@ -116,7 +119,7 @@ class TwoTreeLikelihood:
     TwoTreeLikelihood(
       const std::string& seq1, const std::string& seq2,  
       const SiteContainer& data,
-      SubstitutionModel* model,
+      TransitionModel* model,
       DiscreteDistribution* rDist,
       bool verbose)  throw (Exception);
 
@@ -159,8 +162,8 @@ class TwoTreeLikelihood:
     double getLogLikelihoodForASite(size_t site) const;
     ParameterList getBranchLengthsParameters() const;
     ParameterList getSubstitutionModelParameters() const;
-    SubstitutionModel* getSubstitutionModel(int nodeId, size_t siteIndex) throw (NodeNotFoundException) { return model_; }
-    const SubstitutionModel* getSubstitutionModel(int nodeId, size_t siteIndex) const throw (NodeNotFoundException) { return model_; }
+    TransitionModel* getSubstitutionModel(int nodeId, size_t siteIndex) throw (NodeNotFoundException) { return model_; }
+    const TransitionModel* getSubstitutionModel(int nodeId, size_t siteIndex) const throw (NodeNotFoundException) { return model_; }
     const std::vector<double>& getRootFrequencies(size_t siteIndex) const { return model_->getFrequencies(); }
     size_t getSiteIndex(size_t site) const throw (IndexOutOfBoundsException) { return rootPatternLinks_[site]; }
     /**
@@ -187,14 +190,14 @@ class TwoTreeLikelihood:
      *
      * @return A const pointer toward the substitution model of this instance.
      */
-    const SubstitutionModel* getSubstitutionModel() const { return model_; }
+    const TransitionModel* getSubstitutionModel() const { return model_; }
     
     /**
      * @brief Get the substitution model used for the computation.
      *
      * @return A pointer toward the substitution model of this instance.
      */
-    SubstitutionModel* getSubstitutionModel() { return model_; }
+    TransitionModel* getSubstitutionModel() { return model_; }
 
     ConstBranchModelIterator* getNewBranchModelIterator(int nodeId) const throw (NotImplementedException)
     {
@@ -307,8 +310,8 @@ class DistanceEstimation:
   public virtual Clonable
 {
   private:
-    auto_ptr<SubstitutionModel> model_;
-    auto_ptr<DiscreteDistribution> rateDist_;
+    std::unique_ptr<TransitionModel> model_;
+    std::unique_ptr<DiscreteDistribution> rateDist_;
     const SiteContainer* sites_;
     DistanceMatrix* dist_;
     Optimizer* optimizer_;
@@ -333,7 +336,7 @@ class DistanceEstimation:
      *  - 4=3 + likelihood object verbose enabled
      */
     DistanceEstimation(
-        SubstitutionModel* model,
+        TransitionModel* model,
         DiscreteDistribution* rateDist,
         size_t verbose = 1) :
       model_(model),
@@ -366,7 +369,7 @@ class DistanceEstimation:
      *  @param computeMat if true the computeMatrix() method is called.
      */
     DistanceEstimation(
-        SubstitutionModel* model,
+        TransitionModel* model,
         DiscreteDistribution* rateDist,
         const SiteContainer* sites,
         size_t verbose = 1,
@@ -438,12 +441,7 @@ class DistanceEstimation:
       delete optimizer_;
     }
 
-#ifndef NO_VIRTUAL_COV
-    DistanceEstimation*
-#else
-    Clonable*
-#endif
-    clone() const { return new DistanceEstimation(*this); }
+    DistanceEstimation* clone() const { return new DistanceEstimation(*this); }
     
   private:
     void init_()
@@ -481,16 +479,16 @@ class DistanceEstimation:
      */
     DistanceMatrix* getMatrix() const { return dist_ == 0 ? 0 : new DistanceMatrix(*dist_); }
 
-    bool hasSubstitutionModel() const { return model_.get(); }
+    bool hasModel() const { return model_.get(); }
 
-    const SubstitutionModel& getSubstitutionModel() const throw (Exception) {
-      if (hasSubstitutionModel())
+    const TransitionModel& getSubstitutionModel() const throw (Exception) {
+      if (hasModel())
         return *model_;
       else
         throw Exception("DistanceEstimation::getSubstitutionModel(). No model assciated to this instance.");
     }
 
-    void resetSubstitutionModel(SubstitutionModel* model = 0) { model_.reset(model); }
+    void resetSubstitutionModel(TransitionModel* model = 0) { model_.reset(model); }
 
     bool hasRateDistribution() const { return rateDist_.get(); }
 
