@@ -47,6 +47,7 @@
 
 //From bpp-core:
 #include <Bpp/Io/FileTools.h>
+#include <Bpp/Io/BppOParametrizableFormat.h>
 #include <Bpp/Text/TextTools.h>
 #include <Bpp/Text/StringTokenizer.h>
 #include <Bpp/Text/KeyvalTools.h>
@@ -63,6 +64,8 @@ using namespace bpp;
 // From the STL:
 #include <iomanip>
 
+#include "BppOSubstitutionModelFormat.h"
+
 using namespace std;
 
 unsigned char BppOFrequenciesSetFormat::DNA = 1;
@@ -79,7 +82,7 @@ FrequenciesSet* BppOFrequenciesSetFormat::read(const Alphabet* alphabet, const s
   string freqName;
   map<string, string> args;
   KeyvalTools::parseProcedure(freqDescription, freqName, args);
-  auto_ptr<FrequenciesSet> pFS;
+  unique_ptr<FrequenciesSet> pFS;
 
   if (freqName == "Fixed")
   {
@@ -186,7 +189,7 @@ FrequenciesSet* BppOFrequenciesSetFormat::read(const Alphabet* alphabet, const s
       }
 
       BppOFrequenciesSetFormat nestedReader(alphabetCode_, false, warningLevel_);
-      auto_ptr<FrequenciesSet> pFS2(nestedReader.read(pWA->getNAlphabet(0), sAFS, data, false));
+      unique_ptr<FrequenciesSet> pFS2(nestedReader.read(pWA->getNAlphabet(0), sAFS, data, false));
       map<string, string> unparsedParameterValuesNested(nestedReader.getUnparsedArguments());
       for (map<string, string>::iterator it = unparsedParameterValuesNested.begin(); it != unparsedParameterValuesNested.end(); it++)
       {
@@ -225,6 +228,26 @@ FrequenciesSet* BppOFrequenciesSetFormat::read(const Alphabet* alphabet, const s
       pFS.reset(new WordFromIndependentFrequenciesSet(pWA, v_AFS));
     }
   }
+  //From Model
+  else if (freqName == "FromModel")
+  {
+    if (args.find("model") == args.end())
+      throw Exception("Missing argument 'model' for frequencies " + freqName + ".");
+    
+    BppOSubstitutionModelFormat nestedReader(alphabetCode_, false, true, false, false, warningLevel_);
+    if (geneticCode_)
+      nestedReader.setGeneticCode(geneticCode_);
+
+    TransitionModel* model=nestedReader.read(alphabet, args["model"], data, false);
+    pFS.reset(new FromModelFrequenciesSet(model));
+    map<string, string> unparsedParameterValuesNested(nestedReader.getUnparsedArguments());
+    for (map<string, string>::iterator it = unparsedParameterValuesNested.begin(); it != unparsedParameterValuesNested.end(); it++)
+    {
+      unparsedArguments_["FromModel." + it->first] = it->second;
+    }
+  }
+  
+  
   // INDEPENDENT CODON
   else if (freqName == "Codon")
   {
@@ -243,7 +266,7 @@ FrequenciesSet* BppOFrequenciesSetFormat::read(const Alphabet* alphabet, const s
       string sAFS = args["frequency"];
 
       BppOFrequenciesSetFormat nestedReader(alphabetCode_, false, warningLevel_);
-      auto_ptr<FrequenciesSet> pFS2(nestedReader.read(pWA->getNAlphabet(0), sAFS, data, false));
+      unique_ptr<FrequenciesSet> pFS2(nestedReader.read(pWA->getNAlphabet(0), sAFS, data, false));
       map<string, string> unparsedParameterValuesNested(nestedReader.getUnparsedArguments());
 
       for (map<string, string>::iterator it = unparsedParameterValuesNested.begin(); it != unparsedParameterValuesNested.end(); it++)
@@ -314,7 +337,7 @@ FrequenciesSet* BppOFrequenciesSetFormat::read(const Alphabet* alphabet, const s
     {
       string sPFS = args["protein_frequencies"];
       BppOFrequenciesSetFormat nestedReader(alphabetCode_, false, warningLevel_);
-      auto_ptr<ProteinFrequenciesSet> pPFS(dynamic_cast<ProteinFrequenciesSet*>(nestedReader.read(pPA, sPFS, data, false)));
+      unique_ptr<ProteinFrequenciesSet> pPFS(dynamic_cast<ProteinFrequenciesSet*>(nestedReader.read(pPA, sPFS, data, false)));
       map<string, string> unparsedParameterValuesNested(nestedReader.getUnparsedArguments());
 
       for (map<string, string>::iterator it = unparsedParameterValuesNested.begin(); it != unparsedParameterValuesNested.end(); it++)
@@ -353,26 +376,30 @@ FrequenciesSet* BppOFrequenciesSetFormat::read(const Alphabet* alphabet, const s
     {
       opt = CodonFrequenciesSet::F1X4;
       
-      if (args.find("mgmtStopCodon") != args.end()){
+      if (args.find("mgmtStopCodons") != args.end())
+        mgmtStopCodon = args["mgmtStopCodons"];
+      else if (args.find("mgmtStopCodon") != args.end())
         mgmtStopCodon = args["mgmtStopCodon"];
-        ApplicationTools::displayResult("StopCodon frequencies distribution ", mgmtStopCodon);
-      }
+      
+      ApplicationTools::displayResult("StopCodon frequencies distribution ", mgmtStopCodon);
+
       if (args.find("frequency") != args.end())
+      {
+        string sAFS = args["frequency"];
+        
+        BppOFrequenciesSetFormat nestedReader(alphabetCode_, false, warningLevel_);
+        unique_ptr<FrequenciesSet> pFS2(nestedReader.read(pWA->getNAlphabet(0), sAFS, data, false));
+        if (pFS2->getName()!="Full")
+          throw Exception("BppOFrequenciesSetFormat::read. The frequency option in F1X4 can only be Full");
+        
+        map<string, string> unparsedParameterValuesNested(nestedReader.getUnparsedArguments());
+        
+        for (map<string, string>::iterator it = unparsedParameterValuesNested.begin(); it != unparsedParameterValuesNested.end(); it++)
         {
-          string sAFS = args["frequency"];
-
-          BppOFrequenciesSetFormat nestedReader(alphabetCode_, false, warningLevel_);
-          auto_ptr<FrequenciesSet> pFS2(nestedReader.read(pWA->getNAlphabet(0), sAFS, data, false));
-          if (pFS2->getName()!="Full")
-            throw Exception("BppOFrequenciesSetFormat::read. The frequency option in F1X4 can only be Full");
-            
-          map<string, string> unparsedParameterValuesNested(nestedReader.getUnparsedArguments());
-
-          for (map<string, string>::iterator it = unparsedParameterValuesNested.begin(); it != unparsedParameterValuesNested.end(); it++)
-            {
-              unparsedArguments_["123_" + it->first] = it->second;
-            }
+          unparsedArguments_["123_" + it->first] = it->second;
         }
+      }
+      
       if (args.find("123_theta") != args.end())
           unparsedArguments_["123_Full.theta"] = args["123_theta"];
       if (args.find("123_theta1") != args.end())
@@ -390,10 +417,12 @@ FrequenciesSet* BppOFrequenciesSetFormat::read(const Alphabet* alphabet, const s
     {
       opt = CodonFrequenciesSet::F3X4;
 
-      if (args.find("mgmtStopCodon") != args.end()){
-        mgmtStopCodon = args["mgmtStopCodon"];
-        ApplicationTools::displayResult("StopCodon frequencies distribution ", mgmtStopCodon);
-      }
+      if (args.find("mgmtStopCodons") != args.end())
+        mgmtStopCodon = args["mgmtStopCodons"];
+      else if (args.find("mgmtStopCodon") != args.end())
+          mgmtStopCodon = args["mgmtStopCodon"];
+      
+      ApplicationTools::displayResult("StopCodon frequencies distribution ", mgmtStopCodon);
 
       if (args.find("frequency1") != args.end() ||
           args.find("frequency2") != args.end() ||
@@ -455,12 +484,13 @@ FrequenciesSet* BppOFrequenciesSetFormat::read(const Alphabet* alphabet, const s
   //MVAprotein freq set for COaLA model
   else if (freqName == "MVAprotein")
   {
-	  pFS.reset(new MvaFrequenciesSet(dynamic_cast<const ProteicAlphabet*>(alphabet)));
-	  dynamic_cast<MvaFrequenciesSet*>(pFS.get())->setParamValues(args);
+    pFS.reset(new MvaFrequenciesSet(dynamic_cast<const ProteicAlphabet*>(alphabet)));
+    dynamic_cast<MvaFrequenciesSet*>(pFS.get())->setParamValues(args);
   }
   else
     throw Exception("Unknown frequency option: " + freqName);
 
+  // Update parameter args:
   vector<string> pnames = pFS->getParameters().getParameterNames();
 
   string pref = pFS->getNamespace();
@@ -471,30 +501,71 @@ FrequenciesSet* BppOFrequenciesSetFormat::read(const Alphabet* alphabet, const s
       unparsedArguments_[pref + name] = args[name];
   }
 
+  // Now look if some parameters are aliased:
+  ParameterList pl = pFS->getIndependentParameters();
+  string pname, pval, pname2;
+  for (size_t i = 0; i < pl.size(); i++)
+  {
+    pname = pFS->getParameterNameWithoutNamespace(pl[i].getName());
+
+    if (args.find(pname) == args.end())
+      continue;
+    pval = args[pname];
+
+    if (((pval.rfind("_") != string::npos) && (TextTools::isDecimalInteger(pval.substr(pval.rfind("_")+1,string::npos)))) ||
+        (pval.find("(") != string::npos))
+      continue;
+    bool found = false;
+    for (size_t j = 0; j < pl.size() && !found; j++)
+    {
+      pname2 = pFS->getParameterNameWithoutNamespace(pl[j].getName());
+
+      // if (j == i || args.find(pname2) == args.end()) continue; Julien 03/03/2010: This extra condition prevents complicated (nested) models to work properly...
+      if (j == i)
+        continue;
+      if (pval == pname2)
+      {
+        // This is an alias...
+        // NB: this may throw an exception if uncorrect! We leave it as is for now :s
+        pFS->aliasParameters(pname2, pname);
+        if (verbose_)
+          ApplicationTools::displayResult("Parameter alias found", pname + "->" + pname2);
+        found = true;
+      }
+    }
+    // if (!TextTools::isDecimalNumber(pval) && !found)
+    //   throw Exception("Incorrect parameter syntax: parameter " + pval + " was not found and can't be used as a value for parameter " + pname + ".");
+  }
+
   // Forward arguments:
   if (args.find("init") != args.end())
   {
     unparsedArguments_["init"] = args["init"];
     unparsedArguments_["initFreqs"] = args["init"];
   }
+  
   if (args.find("init.observedPseudoCount") != args.end())
   {
     unparsedArguments_["init.observedPseudoCount"] = args["init.observedPseudoCount"];
     unparsedArguments_["initFreqs.observedPseudoCount"] = args["init.observedPseudoCount"];
   }
+
   if (args.find("values") != args.end())
   {
     unparsedArguments_["initFreqs"] = "values" + args["values"];
     unparsedArguments_["init"] = "values" + args["values"];
+    initialize_(*pFS, data);    
   }
+  else 
+    if (parseArguments)
+      initialize_(*pFS, data);
 
-  if (parseArguments)
-    initialize_(*pFS, data);
   return pFS.release();
 }
 
 void BppOFrequenciesSetFormat::write(const FrequenciesSet* pfreqset,
                                      OutputStream& out,
+                                     std::map<std::string, std::string>& globalAliases,
                                      std::vector<std::string>& writtenNames) const
 {
   if (!pfreqset)
@@ -503,14 +574,16 @@ void BppOFrequenciesSetFormat::write(const FrequenciesSet* pfreqset,
     return;
   }
   ParameterList pl = pfreqset->getParameters();
+
   int p = out.getPrecision();
   out.setPrecision(12);
-  bool flag(false);
+  bool comma(false);
   string name = pfreqset->getName();
   out << name << "(";
 
-
-  if ((name == "Fixed") || (name == "F0"))
+  bool oValues=false;
+  
+  if ((name == "Fixed") || (name == "F0") || (name== "Full"))
   {
     vector<double> vf = pfreqset->getFrequencies();
     out << "values=(";
@@ -521,93 +594,136 @@ void BppOFrequenciesSetFormat::write(const FrequenciesSet* pfreqset,
       out << vf[i];
     }
     out << ")";
-  }
-  else
-  {
-    if (dynamic_cast<const FullProteinFrequenciesSet*>(pfreqset))
-    {
-      size_t meth=dynamic_cast<const FullProteinFrequenciesSet*>(pfreqset)->getMethod();
-      if (meth>1){
-        if (flag)
-          out << ",";
-        out << "method=" << ((meth==2)?"local":"binary");
-        flag=true;
-      }
-    }
-    else
-    {
-      if (name != "F1X4" && name != "F3X4" && name != "F61")
-      {
-        const WordFromIndependentFrequenciesSet* pWFI = dynamic_cast<const WordFromIndependentFrequenciesSet*>(pfreqset);
-        if (pWFI != NULL)
-        {
-          for (size_t i = 0; i < pWFI->getLength(); i++)
-          {
-            if (i != 0)
-              out << ", ";
-            out << "frequency" << i + 1 << "=";
-            write(&pWFI->getFrequenciesSetForLetter(i), out, writtenNames);
-          }
-          flag = true;
-        }
-        const WordFromUniqueFrequenciesSet* pWFU = dynamic_cast<const WordFromUniqueFrequenciesSet*>(pfreqset);
-        if (pWFU != NULL)
-        {
-          for (size_t i = 0; i < pWFU->getLength(); i++)
-          {
-            if (i != 0)
-              out << ", ";
-            out << "frequency=";
-            write(&pWFU->getFrequenciesSetForLetter(i), out, writtenNames);
-          }
-          flag = true;
-        }
-        const FullPerAACodonFrequenciesSet* pFPA=dynamic_cast<const FullPerAACodonFrequenciesSet*>(pfreqset);
-        if (pFPA != NULL)
-        {
-          const ProteinFrequenciesSet* ppfs=pFPA->getProteinFrequenciesSet();
-          out << "protein_frequencies=";
-          
-          write(ppfs, out, writtenNames);
-      
-          flag = true;
-              
-          unsigned short meth=pFPA->getMethod();
-          if (meth>1){
-            if (flag)
-              out << ",";
-            out << "method=" << ((meth==2)?"local":"binary");
-            flag=true;
-          }
-        }
-      }
-    }
 
+    vector<string> npl=pl.getParameterNames();
+    writtenNames.insert(writtenNames.end(), npl.begin(), npl.end());
+
+    comma=true;
     
-    for (size_t i = 0; i < pl.size(); i++)
+    oValues=true;
+  }
+
+  
+  // For Word or Codon FS : length mgmt
+  const WordFromIndependentFrequenciesSet* pWFI = dynamic_cast<const WordFromIndependentFrequenciesSet*>(pfreqset);
+  if (name != "F3X4" && pWFI != NULL)
+  {
+    for (size_t i = 0; i < pWFI->getLength(); i++)
     {
-      if (find(writtenNames.begin(), writtenNames.end(), pl[i].getName()) == writtenNames.end())
-      {
-        if (flag)
-          out << ",";
-        else
-          flag = true;
-        string pname = pfreqset->getParameterNameWithoutNamespace(pl[i].getName());
-        (out << pname << "=").enableScientificNotation(false) << pl[i].getValue();
-        writtenNames.push_back(pl[i].getName());
-      }
+      if (i != 0)
+        out << ", ";
+      out << "frequency" << i + 1 << "=";
+      write(&pWFI->getFrequenciesSetForLetter(i), out, globalAliases, writtenNames);
     }
-    const FullCodonFrequenciesSet* pF=dynamic_cast<const FullCodonFrequenciesSet*>(pfreqset);
-    if (pF != NULL)
+      comma = true;
+  }
+  
+  const WordFromUniqueFrequenciesSet* pWFU = dynamic_cast<const WordFromUniqueFrequenciesSet*>(pfreqset);
+  if (name != "F1X4" && pWFU != NULL)
+  {
+    for (size_t i = 0; i < pWFU->getLength(); i++)
     {
-      unsigned short meth=pF->getMethod();
-      if (meth>1){
-        if (flag)
-          out << ",";
-        out << "method=" << ((meth==2)?"local":"binary");
-        flag=true;
-      }
+      if (i != 0)
+        out << ", ";
+      out << "frequency=";
+      write(&pWFU->getFrequenciesSetForLetter(i), out, globalAliases, writtenNames);
     }
+    comma = true;
+  }
+
+  //FromModel
+
+  const FromModelFrequenciesSet* pFMFS = dynamic_cast<const FromModelFrequenciesSet*>(pfreqset);
+  if (pFMFS != NULL)
+  {
+    if (comma)
+      out << ", ";
+    out << "model=";
+    
+    BppOSubstitutionModelFormat bIO(BppOSubstitutionModelFormat::ALL, true, true, true, false, 0);
+
+    bIO.write(*(pFMFS->getModel()), out, globalAliases, writtenNames);
+    comma = true;
+  }
+
+  
+  // FullPerAA
+  const FullPerAACodonFrequenciesSet* pFPA=dynamic_cast<const FullPerAACodonFrequenciesSet*>(pfreqset);
+  if (pFPA != NULL)
+  {
+    const ProteinFrequenciesSet* ppfs=pFPA->getProteinFrequenciesSet();
+    out << "protein_frequencies=";
+    
+    write(ppfs, out, globalAliases, writtenNames);
+    
+    comma = true;
+    
+    unsigned short meth=pFPA->getMethod();
+    if (meth>1){
+      if (comma)
+        out << ",";
+      out << "method=" << ((meth==2)?"local":"binary");
+      comma=true;
+    }
+  }
+
+
+  // method 
+  if (dynamic_cast<const FullProteinFrequenciesSet*>(pfreqset))
+  {
+    size_t meth=dynamic_cast<const FullProteinFrequenciesSet*>(pfreqset)->getMethod();
+    if (meth>1){
+      if (comma)
+        out << ",";
+      out << "method=" << ((meth==2)?"local":"binary");
+      comma=true;
+    }
+  }
+  
+  const FullCodonFrequenciesSet* pF=dynamic_cast<const FullCodonFrequenciesSet*>(pfreqset);
+  if (pF != NULL)
+  {
+    unsigned short meth=pF->getMethod();
+    if (meth>1){
+      if (comma)
+        out << ",";
+      out << "method=" << ((meth==2)?"local":"binary");
+      comma=true;
+    }
+  }
+
+  // mgmtStopCodon 
+  const CodonFromUniqueFrequenciesSet* pCFU = dynamic_cast<const CodonFromUniqueFrequenciesSet*>(pfreqset);
+  if (pCFU != NULL)
+  {
+    if (pCFU->getMgmtStopCodon()!="quadratic")
+    {
+      if (comma)
+        out << ",";
+      out << "mgmtStopCodons=" << pCFU->getMgmtStopCodon();
+      comma = true;
+    }
+  }
+    
+  const CodonFromIndependentFrequenciesSet* pCFI = dynamic_cast<const CodonFromIndependentFrequenciesSet*>(pfreqset);
+  if (pCFI != NULL)
+  {
+    if (pCFI->getMgmtStopCodon()!="quadratic")
+    {
+      if (comma)
+        out << ",";
+      out << "mgmtStopCodons=" << pCFI->getMgmtStopCodon();
+      comma = true;
+    }
+  }
+
+// All remaining parameters
+  if (!oValues)
+  {
+    const BppOParametrizableFormat* bIO = new BppOParametrizableFormat();
+  
+    bIO->write(pfreqset, out, globalAliases, pl.getParameterNames(), writtenNames, true, comma);
+    delete bIO;
   }
   
   out << ")";
@@ -620,6 +736,7 @@ void BppOFrequenciesSetFormat::initialize_(FrequenciesSet& freqSet, const SiteCo
   {
     // Initialization using the "init" option
     string init = unparsedArguments_["init"];
+
     if (init == "observed")
     {
       if (!data)
@@ -650,12 +767,15 @@ void BppOFrequenciesSetFormat::initialize_(FrequenciesSet& freqSet, const SiteCo
     }
     else
       throw Exception("Unknown init argument");
+
+    unparsedArguments_.erase(unparsedArguments_.find("init"));
+    unparsedArguments_.erase(unparsedArguments_.find("initFreqs"));    
   }
   else
   {
     // Explicit initialization of each parameter
-    ParameterList pl = freqSet.getParameters();
-
+    ParameterList pl = freqSet.getIndependentParameters();
+      
     for (size_t i = 0; i < pl.size(); ++i)
     {
       AutoParameter ap(pl[i]);
@@ -667,13 +787,21 @@ void BppOFrequenciesSetFormat::initialize_(FrequenciesSet& freqSet, const SiteCo
     for (size_t i = 0; i < pl.size(); ++i)
     {
       const string pName = pl[i].getName();
-      double value = ApplicationTools::getDoubleParameter(pName, unparsedArguments_, pl[i].getValue(), "", true, warningLevel_);
+      
+      try {
+        double value = ApplicationTools::getDoubleParameter(pName, unparsedArguments_, pl[i].getValue(), "", true, warningLevel_);
 
-      pl[i].setValue(value);
-      if (verbose_)
-        ApplicationTools::displayResult("Parameter found", pName + "=" + TextTools::toString(pl[i].getValue()));
+        pl[i].setValue(value);
+
+        if (unparsedArguments_.find(pName) != unparsedArguments_.end())
+          unparsedArguments_.erase(unparsedArguments_.find(pName));
+
+        if (verbose_)
+          ApplicationTools::displayResult("Parameter found", pName + "=" + TextTools::toString(pl[i].getValue()));
+      }
+      catch (Exception& e) {}
     }
-
+    
     freqSet.matchParametersValues(pl);
   }
 }
