@@ -58,7 +58,7 @@ using namespace std;
 
 AbstractHomogeneousTreeLikelihood::AbstractHomogeneousTreeLikelihood(
   const Tree& tree,
-  SubstitutionModel* model,
+  TransitionModel* model,
   DiscreteDistribution* rDist,
   bool checkRooted,
   bool verbose)
@@ -132,7 +132,8 @@ AbstractHomogeneousTreeLikelihood& AbstractHomogeneousTreeLikelihood::operator=(
   verbose_         = lik.verbose_;
   minimumBrLen_    = lik.minimumBrLen_;
   maximumBrLen_    = lik.maximumBrLen_;
-  if (brLenConstraint_.get()) brLenConstraint_.release();
+  if (brLenConstraint_.get())
+    brLenConstraint_.release();
   brLenConstraint_.reset(lik.brLenConstraint_->clone());
   return *this;
 }
@@ -141,7 +142,7 @@ AbstractHomogeneousTreeLikelihood& AbstractHomogeneousTreeLikelihood::operator=(
 
 void AbstractHomogeneousTreeLikelihood::init_(
   const Tree& tree,
-  SubstitutionModel* model,
+  TransitionModel* model,
   DiscreteDistribution* rDist,
   bool checkRooted,
   bool verbose) throw (Exception)
@@ -169,7 +170,7 @@ void AbstractHomogeneousTreeLikelihood::init_(
 
 /******************************************************************************/
 
-void AbstractHomogeneousTreeLikelihood::setSubstitutionModel(SubstitutionModel* model) throw (Exception)
+void AbstractHomogeneousTreeLikelihood::setSubstitutionModel(TransitionModel* model) throw (Exception)
 {
   // Check:
   if (data_)
@@ -183,7 +184,7 @@ void AbstractHomogeneousTreeLikelihood::setSubstitutionModel(SubstitutionModel*
   if (data_)
   {
     if (model->getNumberOfStates() != model_->getNumberOfStates())
-      setData(*data_);  // Have to reinitialize the whole data structure.
+      setData(*data_);                          // Have to reinitialize the whole data structure.
   }
 
   nbStates_ = model->getNumberOfStates();
@@ -304,7 +305,7 @@ void AbstractHomogeneousTreeLikelihood::applyParameters() throw (Exception)
 
 /******************************************************************************/
 
-void AbstractHomogeneousTreeLikelihood::initBranchLengthsParameters()
+void AbstractHomogeneousTreeLikelihood::initBranchLengthsParameters(bool verbose)
 {
   brLenParameters_.reset();
   for (unsigned int i = 0; i < nbNodes_; i++)
@@ -312,7 +313,8 @@ void AbstractHomogeneousTreeLikelihood::initBranchLengthsParameters()
     double d = minimumBrLen_;
     if (!nodes_[i]->hasDistanceToFather())
     {
-      ApplicationTools::displayWarning("Missing branch length " + TextTools::toString(i) + ". Value is set to " + TextTools::toString(minimumBrLen_));
+      if (verbose)
+        ApplicationTools::displayWarning("Missing branch length " + TextTools::toString(i) + ". Value is set to " + TextTools::toString(minimumBrLen_));
       nodes_[i]->setDistanceToFather(minimumBrLen_);
     }
     else
@@ -320,13 +322,15 @@ void AbstractHomogeneousTreeLikelihood::initBranchLengthsParameters()
       d = nodes_[i]->getDistanceToFather();
       if (d < minimumBrLen_)
       {
-        ApplicationTools::displayWarning("Branch length " + TextTools::toString(i) + " is too small: " + TextTools::toString(d) + ". Value is set to " + TextTools::toString(minimumBrLen_));
+        if (verbose)
+          ApplicationTools::displayWarning("Branch length " + TextTools::toString(i) + " is too small: " + TextTools::toString(d) + ". Value is set to " + TextTools::toString(minimumBrLen_));
         nodes_[i]->setDistanceToFather(minimumBrLen_);
         d = minimumBrLen_;
       }
       if (d > maximumBrLen_)
       {
-        ApplicationTools::displayWarning("Branch length " + TextTools::toString(i) + " is too big: " + TextTools::toString(d) + ". Value is set to " + TextTools::toString(maximumBrLen_));
+        if (verbose)
+          ApplicationTools::displayWarning("Branch length " + TextTools::toString(i) + " is too big: " + TextTools::toString(d) + ". Value is set to " + TextTools::toString(maximumBrLen_));
         nodes_[i]->setDistanceToFather(maximumBrLen_);
         d = maximumBrLen_;
       }
@@ -370,7 +374,7 @@ void AbstractHomogeneousTreeLikelihood::computeTransitionProbabilitiesForNode(co
       }
     }
   }
-  
+
   if (computeFirstOrderDerivatives_)
   {
     // Computes all dpxy/dt once for all:
@@ -413,4 +417,3 @@ void AbstractHomogeneousTreeLikelihood::computeTransitionProbabilitiesForNode(co
 }
 
 /*******************************************************************************/
-
