@@ -79,7 +79,7 @@ AbstractNonHomogeneousTreeLikelihood::AbstractNonHomogeneousTreeLikelihood(
   verbose_(),
   minimumBrLen_(),
   maximumBrLen_(),
-  brLenConstraint_(0),
+  brLenConstraint_(),
   reparametrizeRoot_(reparametrizeRoot),
   root1_(),
   root2_()
@@ -316,26 +316,26 @@ void AbstractNonHomogeneousTreeLikelihood::applyParameters() throw (Exception)
   if (!initialized_) throw Exception("AbstractBranchNonHomogeneousTreeLikelihood::applyParameters(). Object not initialized.");
   //Apply branch lengths:
   for (unsigned int i = 0; i < nbNodes_; i++)
+  {
+    int id = nodes_[i]->getId();
+    if (reparametrizeRoot_ && id == root1_)
     {
-      int id = nodes_[i]->getId();
-      if (reparametrizeRoot_ && id == root1_)
-        {
-          const Parameter* rootBrLen = &getParameter("BrLenRoot");
-          const Parameter* rootPos = &getParameter("RootPosition");
-          nodes_[i]->setDistanceToFather(rootBrLen->getValue() * rootPos->getValue());
-        }
-      else if (reparametrizeRoot_ && id == root2_)
-        {
-          const Parameter* rootBrLen = &getParameter("BrLenRoot");
-          const Parameter* rootPos = &getParameter("RootPosition");
-          nodes_[i]->setDistanceToFather(rootBrLen->getValue() * (1. - rootPos->getValue()));
-        }
-      else
-        {
-          const Parameter* brLen = &getParameter(string("BrLen") + TextTools::toString(i));
-          if (brLen) nodes_[i]->setDistanceToFather(brLen->getValue());
-        }
+      const Parameter* rootBrLen = &getParameter("BrLenRoot");
+      const Parameter* rootPos = &getParameter("RootPosition");
+      nodes_[i]->setDistanceToFather(rootBrLen->getValue() * rootPos->getValue());
     }
+    else if (reparametrizeRoot_ && id == root2_)
+    {
+      const Parameter* rootBrLen = &getParameter("BrLenRoot");
+      const Parameter* rootPos = &getParameter("RootPosition");
+      nodes_[i]->setDistanceToFather(rootBrLen->getValue() * (1. - rootPos->getValue()));
+    }
+    else
+    {
+      const Parameter* brLen = &getParameter(string("BrLen") + TextTools::toString(i));
+      if (brLen) nodes_[i]->setDistanceToFather(brLen->getValue());
+    }
+  }
   //Apply substitution model parameters:
 
   modelSet_->matchParametersValues(getParameters());
@@ -345,7 +345,7 @@ void AbstractNonHomogeneousTreeLikelihood::applyParameters() throw (Exception)
 
 /******************************************************************************/
 
-void AbstractNonHomogeneousTreeLikelihood::initBranchLengthsParameters()
+void AbstractNonHomogeneousTreeLikelihood::initBranchLengthsParameters(bool verbose)
 {
   brLenParameters_.reset();
   double l1 = 0, l2 = 0;
@@ -354,7 +354,8 @@ void AbstractNonHomogeneousTreeLikelihood::initBranchLengthsParameters()
       double d = minimumBrLen_;
       if (!nodes_[i]->hasDistanceToFather())
         {
-          ApplicationTools::displayWarning("Missing branch length " + TextTools::toString(i) + ". Value is set to " + TextTools::toString(minimumBrLen_));
+          if (verbose)
+            ApplicationTools::displayWarning("Missing branch length " + TextTools::toString(i) + ". Value is set to " + TextTools::toString(minimumBrLen_));
           nodes_[i]->setDistanceToFather(minimumBrLen_);
         }
       else
@@ -362,13 +363,15 @@ void AbstractNonHomogeneousTreeLikelihood::initBranchLengthsParameters()
           d = nodes_[i]->getDistanceToFather();
           if (d < minimumBrLen_)
             {
-              ApplicationTools::displayWarning("Branch length " + TextTools::toString(i) + " is too small: " + TextTools::toString(d) + ". Value is set to " + TextTools::toString(minimumBrLen_));
+              if (verbose)
+                ApplicationTools::displayWarning("Branch length " + TextTools::toString(i) + " is too small: " + TextTools::toString(d) + ". Value is set to " + TextTools::toString(minimumBrLen_));
               nodes_[i]->setDistanceToFather(minimumBrLen_);
               d = minimumBrLen_;
             }
           if (d > maximumBrLen_)
             {
-              ApplicationTools::displayWarning("Branch length " + TextTools::toString(i) + " is too big: " + TextTools::toString(d) + ". Value is set to " + TextTools::toString(maximumBrLen_));
+              if (verbose)
+                ApplicationTools::displayWarning("Branch length " + TextTools::toString(i) + " is too big: " + TextTools::toString(d) + ". Value is set to " + TextTools::toString(maximumBrLen_));
               nodes_[i]->setDistanceToFather(maximumBrLen_);
               d = maximumBrLen_;
             }
@@ -405,7 +408,7 @@ void AbstractNonHomogeneousTreeLikelihood::computeAllTransitionProbabilities()
 
 void AbstractNonHomogeneousTreeLikelihood::computeTransitionProbabilitiesForNode(const Node* node)
 {
-  const SubstitutionModel* model = modelSet_->getModelForNode(node->getId());
+  const TransitionModel* model = modelSet_->getModelForNode(node->getId());
   double l = node->getDistanceToFather(); 
 
   //Computes all pxy and pyx once for all:
