@@ -124,7 +124,7 @@ class AbstractNonHomogeneousTreeLikelihood:
 
     double minimumBrLen_;
     double maximumBrLen_;
-    std::auto_ptr<Constraint> brLenConstraint_;
+    std::unique_ptr<Constraint> brLenConstraint_;
 
     bool reparametrizeRoot_;
     int root1_, root2_;
@@ -193,12 +193,12 @@ class AbstractNonHomogeneousTreeLikelihood:
       return AbstractDiscreteRatesAcrossSitesTreeLikelihood::getRateDistributionParameters();
     }
 
-    const SubstitutionModel* getSubstitutionModelForNode(int nodeId) const throw (NodeNotFoundException) 
+    const TransitionModel* getSubstitutionModelForNode(int nodeId) const throw (NodeNotFoundException) 
     {
       return modelSet_->getModelForNode(nodeId);
     }
 
-    SubstitutionModel* getSubstitutionModelForNode(int nodeId) throw (NodeNotFoundException)
+    TransitionModel* getSubstitutionModelForNode(int nodeId) throw (NodeNotFoundException)
     {
       return modelSet_->getModelForNode(nodeId);
     }
@@ -253,7 +253,7 @@ class AbstractNonHomogeneousTreeLikelihood:
      */
     virtual void applyParameters() throw (Exception);  
 
-    virtual void initBranchLengthsParameters();
+    virtual void initBranchLengthsParameters(bool verbose = true);
 
     virtual void setMinimumBranchLength(double minimum) throw (Exception)
     {
