@@ -5,36 +5,36 @@
 //
 
 /*
-Copyright or © or Copr. Bio++ Development Team, (November 16, 2004)
+  Copyright or © or Copr. Bio++ Development Team, (November 16, 2004)
 
-This software is a computer program whose purpose is to provide classes
-for phylogenetic data analysis.
+  This software is a computer program whose purpose is to provide classes
+  for phylogenetic data analysis.
 
-This software is governed by the CeCILL  license under French law and
-abiding by the rules of distribution of free software.  You can  use, 
-modify and/ or redistribute the software under the terms of the CeCILL
-license as circulated by CEA, CNRS and INRIA at the following URL
-"http://www.cecill.info". 
+  This software is governed by the CeCILL  license under French law and
+  abiding by the rules of distribution of free software.  You can  use, 
+  modify and/ or redistribute the software under the terms of the CeCILL
+  license as circulated by CEA, CNRS and INRIA at the following URL
+  "http://www.cecill.info". 
 
-As a counterpart to the access to the source code and  rights to copy,
-modify and redistribute granted by the license, users are provided only
-with a limited warranty  and the software's author,  the holder of the
-economic rights,  and the successive licensors  have only  limited
-liability. 
+  As a counterpart to the access to the source code and  rights to copy,
+  modify and redistribute granted by the license, users are provided only
+  with a limited warranty  and the software's author,  the holder of the
+  economic rights,  and the successive licensors  have only  limited
+  liability. 
 
-In this respect, the user's attention is drawn to the risks associated
-with loading,  using,  modifying and/or developing or reproducing the
-software by the user in light of its specific status of free software,
-that may mean  that it is complicated to manipulate,  and  that  also
-therefore means  that it is reserved for developers  and  experienced
-professionals having in-depth computer knowledge. Users are therefore
-encouraged to load and test the software's suitability as regards their
-requirements in conditions enabling the security of their systems and/or 
-data to be ensured and,  more generally, to use and operate it in the 
-same conditions as regards security. 
+  In this respect, the user's attention is drawn to the risks associated
+  with loading,  using,  modifying and/or developing or reproducing the
+  software by the user in light of its specific status of free software,
+  that may mean  that it is complicated to manipulate,  and  that  also
+  therefore means  that it is reserved for developers  and  experienced
+  professionals having in-depth computer knowledge. Users are therefore
+  encouraged to load and test the software's suitability as regards their
+  requirements in conditions enabling the security of their systems and/or 
+  data to be ensured and,  more generally, to use and operate it in the 
+  same conditions as regards security. 
 
-The fact that you are presently reading this means that you have had
-knowledge of the CeCILL license and that you accept its terms.
+  The fact that you are presently reading this means that you have had
+  knowledge of the CeCILL license and that you accept its terms.
 */
 
 #ifndef _ABSTRACTTREELIKELIHOOD_H_
@@ -66,10 +66,10 @@ namespace bpp
  * 
  * It also adds an abstract method for recursive computations.
  */
-class AbstractTreeLikelihood :
-  public virtual TreeLikelihood,
-  public AbstractParametrizable
-{
+  class AbstractTreeLikelihood :
+    public virtual TreeLikelihood,
+    public AbstractParametrizable
+  {
   public:
     /**
      * @brief A very simple branch iterator.
@@ -79,23 +79,23 @@ class AbstractTreeLikelihood :
     class SimpleBranchIterator :
       public BranchIterator
     {
-      private:
-        std::vector<int> nodesId_;
-        size_t index_;
+    private:
+      std::vector<int> nodesId_;
+      size_t index_;
 
-      public:
-        SimpleBranchIterator(const std::vector<int>& nodesId) :
-          nodesId_(nodesId), index_(0) {}
+    public:
+      SimpleBranchIterator(const std::vector<int>& nodesId) :
+        nodesId_(nodesId), index_(0) {}
 
-      public:
-        int next() throw (Exception)
-        {
-          if (!hasNext())
-            throw Exception("AbstractTreeLikelihood::SimpleBranchIterator::next(). No more branch in the set.");
-          return nodesId_[index_++];
-        }
+    public:
+      int next() throw (Exception)
+      {
+        if (!hasNext())
+          throw Exception("AbstractTreeLikelihood::SimpleBranchIterator::next(). No more branch in the set.");
+        return nodesId_[index_++];
+      }
 
-        bool hasNext() const { return index_ < nodesId_.size(); }
+      bool hasNext() const { return index_ < nodesId_.size(); }
         
     };
 
@@ -109,24 +109,24 @@ class AbstractTreeLikelihood :
     class SimpleSiteIterator :
       public SiteIterator
     {
-      private:
-        size_t maxIndex_;
-        size_t index_;
-        size_t offset_;
+    private:
+      size_t maxIndex_;
+      size_t index_;
+      size_t offset_;
 
-      public:
-        SimpleSiteIterator(size_t nbSites, size_t offset = 0) :
-          maxIndex_(nbSites), index_(0), offset_(offset) {}
+    public:
+      SimpleSiteIterator(size_t nbSites, size_t offset = 0) :
+        maxIndex_(nbSites), index_(0), offset_(offset) {}
 
-      public:
-        size_t next() throw (Exception)
-        {
-          if (!hasNext())
-            throw Exception("AbstractTreeLikelihood::SimpleSiteIterator::next(). No more site in the set.");
-          return offset_ + index_++;
-        }
+    public:
+      size_t next() throw (Exception)
+      {
+        if (!hasNext())
+          throw Exception("AbstractTreeLikelihood::SimpleSiteIterator::next(). No more site in the set.");
+        return offset_ + index_++;
+      }
 
-        bool hasNext() const { return index_ < maxIndex_; }
+      bool hasNext() const { return index_ < maxIndex_; }
         
     };
    
@@ -138,85 +138,89 @@ class AbstractTreeLikelihood :
     class ConstNoPartitionBranchModelDescription :
       public ConstBranchModelDescription
     {
-      private:
-        const SubstitutionModel* model_;
-        size_t nbSites_;
+    private:
+      const TransitionModel* model_;
+      size_t nbSites_;
 
-      public:
-        ConstNoPartitionBranchModelDescription(const SubstitutionModel* model, size_t nbSites) :
-          model_(model), nbSites_(nbSites) {}
+    public:
+      ConstNoPartitionBranchModelDescription(const TransitionModel* model, size_t nbSites) :
+        model_(model), nbSites_(nbSites) {}
 
-        ConstNoPartitionBranchModelDescription(const ConstNoPartitionBranchModelDescription& bmd) :
-          model_(bmd.model_),
-          nbSites_(bmd.nbSites_)
-        {}
+      ConstNoPartitionBranchModelDescription(const ConstNoPartitionBranchModelDescription& bmd) :
+        model_(bmd.model_),
+        nbSites_(bmd.nbSites_)
+      {}
 
-        ConstNoPartitionBranchModelDescription& operator=(const ConstNoPartitionBranchModelDescription& bmd)
-        {
-          model_ = bmd.model_;
-          nbSites_ = bmd.nbSites_;
-          return *this;
-        }
+      ConstNoPartitionBranchModelDescription& operator=(const ConstNoPartitionBranchModelDescription& bmd)
+      {
+        model_ = bmd.model_;
+        nbSites_ = bmd.nbSites_;
+        return *this;
+      }
 
-      public:
-        const SubstitutionModel* getModel() const { return model_; }
-        
-        SiteIterator* getNewSiteIterator() const { return new SimpleSiteIterator(nbSites_); }
+    public:
+      const TransitionModel* getModel() const { return model_; }
+
+      const SubstitutionModel* getSubstitutionModel() const { return dynamic_cast<const SubstitutionModel*>(model_); }
+
+      SiteIterator* getNewSiteIterator() const { return new SimpleSiteIterator(nbSites_); }
     };
 
     class ConstNoPartitionBranchModelIterator :
       public ConstBranchModelIterator
     {
-      private:
-        ConstNoPartitionBranchModelDescription branchModelDescription_;
-        size_t index_;
+    private:
+      ConstNoPartitionBranchModelDescription branchModelDescription_;
+      size_t index_;
 
-      public:
-        ConstNoPartitionBranchModelIterator(const SubstitutionModel* model, size_t nbSites) :
-          branchModelDescription_(model, nbSites), index_(0) {}
+    public:
+      ConstNoPartitionBranchModelIterator(const TransitionModel* model, size_t nbSites) :
+        branchModelDescription_(model, nbSites), index_(0) {}
 
-      public:
-        ConstNoPartitionBranchModelDescription* next() throw (Exception)
-        {
-          if (!hasNext())
-            throw Exception("AbstractHomogeneousTreeLikelihood::ConstHomogeneousBranchModelIterator::next(). No more branch in the set.");
-          index_++;
-          return &branchModelDescription_;
-        }
+    public:
+      ConstNoPartitionBranchModelDescription* next() throw (Exception)
+      {
+        if (!hasNext())
+          throw Exception("AbstractHomogeneousTreeLikelihood::ConstHomogeneousBranchModelIterator::next(). No more branch in the set.");
+        index_++;
+        return &branchModelDescription_;
+      }
 
-        bool hasNext() const { return index_ == 0; }
+      bool hasNext() const { return index_ == 0; }
     };
  
     class ConstNoPartitionSiteModelDescription :
       public ConstSiteModelDescription
     {
-      private:
-        const SubstitutionModel* model_;
-        std::vector<int> nodesId_;
+    private:
+      const TransitionModel* model_;
+      std::vector<int> nodesId_;
 
-      public:
-        ConstNoPartitionSiteModelDescription(const SubstitutionModel* model, const std::vector<int> nodesId) :
-          model_(model), nodesId_(nodesId) {}
+    public:
+      ConstNoPartitionSiteModelDescription(const TransitionModel* model, const std::vector<int> nodesId) :
+        model_(model), nodesId_(nodesId) {}
 
-        ConstNoPartitionSiteModelDescription(const ConstNoPartitionSiteModelDescription& smd) :
-          model_(smd.model_),
-          nodesId_(smd.nodesId_)
-        {}
+      ConstNoPartitionSiteModelDescription(const ConstNoPartitionSiteModelDescription& smd) :
+        model_(smd.model_),
+        nodesId_(smd.nodesId_)
+      {}
 
-        ConstNoPartitionSiteModelDescription& operator=(const ConstNoPartitionSiteModelDescription& smd)
-        {
-          model_ = smd.model_;
-          nodesId_ = smd.nodesId_;
-          return *this;
-        }
+      ConstNoPartitionSiteModelDescription& operator=(const ConstNoPartitionSiteModelDescription& smd)
+      {
+        model_ = smd.model_;
+        nodesId_ = smd.nodesId_;
+        return *this;
+      }
 
-      public:
-        const SubstitutionModel* getModel() const { return model_; }
+    public:
+      const TransitionModel* getModel() const { return model_; }
         
-        BranchIterator* getNewBranchIterator() const { return new SimpleBranchIterator(nodesId_); }
+      const SubstitutionModel* getSubstitutionModel() const { return dynamic_cast<const SubstitutionModel*>(model_); }
+
+      BranchIterator* getNewBranchIterator() const { return new SimpleBranchIterator(nodesId_); }
     };
 
-   /** @} */
+    /** @} */
 
 
 
@@ -309,7 +313,7 @@ class AbstractTreeLikelihood :
 //     */
 //    virtual void fireParameterChanged(const ParameterList & params) = 0;
     
-};
+  };
 
 } //end of namespace bpp.
 
