@@ -48,7 +48,7 @@ using namespace bpp;
 
 /******************************************************************************/
 
-void DRASDRTreeLikelihoodData::initLikelihoods(const SiteContainer& sites, const SubstitutionModel& model) throw (Exception)
+void DRASDRTreeLikelihoodData::initLikelihoods(const SiteContainer& sites, const TransitionModel& model) throw (Exception)
 {
   if (sites.getNumberOfSequences() == 1)
     throw Exception("Error, only 1 sequence!");
@@ -101,7 +101,7 @@ void DRASDRTreeLikelihoodData::initLikelihoods(const SiteContainer& sites, const
 
 /******************************************************************************/
 
-void DRASDRTreeLikelihoodData::initLikelihoods(const Node* node, const SiteContainer& sites, const SubstitutionModel& model) throw (Exception)
+void DRASDRTreeLikelihoodData::initLikelihoods(const Node* node, const SiteContainer& sites, const TransitionModel& model) throw (Exception)
 {
   if (node->isLeaf())
   {
@@ -125,6 +125,7 @@ void DRASDRTreeLikelihoodData::initLikelihoods(const Node* node, const SiteConta
       leavesLikelihoods_leaf_i->resize(nbStates_);
       int state = seq->getValue(i);
       double test = 0.;
+
       for (size_t s = 0; s < nbStates_; s++)
       {
         // Leaves likelihood are set to 1 if the char correspond to the site in the sequence,
@@ -133,7 +134,7 @@ void DRASDRTreeLikelihoodData::initLikelihoods(const Node* node, const SiteConta
         test += ( *leavesLikelihoods_leaf_i)[s];
       }
       if (test < 0.000001)
-        std::cerr << "WARNING!!! Likelihood will be 0 for this site." << std::endl;
+        std::cerr << "WARNING!!! Likelihood will be 0 for site " << i << std::endl;
     }
   }
 
