@@ -84,12 +84,7 @@ class DRASDRTreeLikelihoodLeafData :
       return *this;
     }
 
-#ifndef NO_VIRTUAL_COV
-    DRASDRTreeLikelihoodLeafData*
-#else
-    Clonable*
-#endif
-    clone() const
+    DRASDRTreeLikelihoodLeafData* clone() const
     { 
       return new DRASDRTreeLikelihoodLeafData(*this);
     }
@@ -173,12 +168,7 @@ class DRASDRTreeLikelihoodNodeData :
  
     virtual ~DRASDRTreeLikelihoodNodeData() {}
 
-#ifndef NO_VIRTUAL_COV
-    DRASDRTreeLikelihoodNodeData*
-#else 
-    Clonable*
-#endif
-    clone() const
+    DRASDRTreeLikelihoodNodeData* clone() const
     { 
       return new DRASDRTreeLikelihoodNodeData(*this);
     }
@@ -414,7 +404,7 @@ class DRASDRTreeLikelihoodData :
      * @param model The substitution model to use.
      * @throw Exception if an error occures.
      */
-    void initLikelihoods(const SiteContainer& sites, const SubstitutionModel& model) throw (Exception);
+    void initLikelihoods(const SiteContainer& sites, const TransitionModel& model) throw (Exception);
     
     /**
      * @brief Rebuild likelihood arrays at inner nodes.
@@ -444,7 +434,7 @@ class DRASDRTreeLikelihoodData :
      * @param sites The sequence container to use.
      * @param model The model, used for initializing leaves' likelihoods.
      */
-    void initLikelihoods(const Node* node, const SiteContainer& sites, const SubstitutionModel& model) throw (Exception);
+    void initLikelihoods(const Node* node, const SiteContainer& sites, const TransitionModel& model) throw (Exception);
     
 };
 
