@@ -48,10 +48,11 @@
 #include <Bpp/Seq/Container/VectorSiteContainer.h>
 
 using namespace bpp;
+using namespace std;
 
 /******************************************************************************/
 
-void DRASRTreeLikelihoodData::initLikelihoods(const SiteContainer& sites, const SubstitutionModel& model)
+void DRASRTreeLikelihoodData::initLikelihoods(const SiteContainer& sites, const TransitionModel& model)
 throw (Exception)
 {
   if (sites.getNumberOfSequences() == 1)
@@ -91,7 +92,7 @@ throw (Exception)
 
 /******************************************************************************/
 
-void DRASRTreeLikelihoodData::initLikelihoods(const Node* node, const SiteContainer& sequences, const SubstitutionModel& model) throw (Exception)
+void DRASRTreeLikelihoodData::initLikelihoods(const Node* node, const SiteContainer& sequences, const TransitionModel& model) throw (Exception)
 {
   // Initialize likelihood vector:
   DRASRTreeLikelihoodNodeData* nodeData = &nodeData_[node->getId()];
@@ -150,16 +151,17 @@ void DRASRTreeLikelihoodData::initLikelihoods(const Node* node, const SiteContai
       {
         Vdouble* _likelihoods_node_i_c = &(*_likelihoods_node_i)[c];
         double test = 0.;
+
         for (size_t s = 0; s < nbStates_; s++)
         {
           // Leaves likelihood are set to 1 if the char correspond to the site in the sequence,
           // otherwise value set to 0:
-          // cout << "i=" << i << "\tc=" << c << "\ts=" << s << endl;
+          
           (*_likelihoods_node_i_c)[s] = model.getInitValue(s, state);
           test += (*_likelihoods_node_i_c)[s];
         }
         if (test < 0.000001)
-          std::cerr << "WARNING!!! Likelihood will be 0 for this site." << std::endl;
+          std::cerr << "WARNING!!! Likelihood will be 0 for site " << i << std::endl;
       }
     }
   }
@@ -188,7 +190,7 @@ void DRASRTreeLikelihoodData::initLikelihoods(const Node* node, const SiteContai
 
 /******************************************************************************/
 
-SitePatterns* DRASRTreeLikelihoodData::initLikelihoodsWithPatterns(const Node* node, const SiteContainer& sequences, const SubstitutionModel& model) throw (Exception)
+SitePatterns* DRASRTreeLikelihoodData::initLikelihoodsWithPatterns(const Node* node, const SiteContainer& sequences, const TransitionModel& model) throw (Exception)
 {
   SiteContainer* tmp = PatternTools::getSequenceSubset(sequences, *node);
   SitePatterns* patterns = new SitePatterns(tmp, true);
@@ -248,6 +250,7 @@ SitePatterns* DRASRTreeLikelihoodData::initLikelihoodsWithPatterns(const Node* n
     {
       VVdouble* _likelihoods_node_i = &(*_likelihoods_node)[i];
       int state = seq->getValue(i);
+      
       for (size_t c = 0; c < nbClasses_; c++)
       {
         Vdouble* _likelihoods_node_i_c = &(*_likelihoods_node_i)[c];
@@ -261,7 +264,7 @@ SitePatterns* DRASRTreeLikelihoodData::initLikelihoodsWithPatterns(const Node* n
           test += (*_likelihoods_node_i_c)[s];
         }
         if (test < 0.000001)
-          std::cerr << "WARNING!!! Likelihood will be 0 for this site." << std::endl;
+          std::cerr << "WARNING!!! Likelihood will be 0 for site " << i << std::endl;
       }
     }
   }
