@@ -98,12 +98,7 @@ class DRASRTreeLikelihoodNodeData :
       return *this;
     }
  
-#ifndef NO_VIRTUAL_COV
-    DRASRTreeLikelihoodNodeData*
-#else
-    Clonable*
-#endif
-    clone() const
+    DRASRTreeLikelihoodNodeData* clone() const
     {
       return new DRASRTreeLikelihoodNodeData(*this);
     }
@@ -266,7 +261,7 @@ class DRASRTreeLikelihoodData :
     size_t getNumberOfStates() const { return nbStates_; }
     size_t getNumberOfClasses() const { return nbClasses_; }
     
-    void initLikelihoods(const SiteContainer& sites, const SubstitutionModel& model) throw (Exception);
+    void initLikelihoods(const SiteContainer& sites, const TransitionModel& model) throw (Exception);
 
   protected:
     /**
@@ -283,7 +278,7 @@ class DRASRTreeLikelihoodData :
      * @param sequences The data to be used for initialization.
      * @param model     The model to use.
      */
-    virtual void initLikelihoods(const Node* node, const SiteContainer& sequences, const SubstitutionModel& model) throw (Exception);
+    virtual void initLikelihoods(const Node* node, const SiteContainer& sequences, const TransitionModel& model) throw (Exception);
 
     /**
      * @brief This method initializes the leaves according to a sequence file.
@@ -301,7 +296,7 @@ class DRASRTreeLikelihoodData :
      * @param model     The model to use.
      * @return The shrunk sub-dataset + indices for the subtree defined by <i>node</i>.
      */
-    virtual SitePatterns* initLikelihoodsWithPatterns(const Node* node, const SiteContainer& sequences, const SubstitutionModel& model) throw (Exception);
+    virtual SitePatterns* initLikelihoodsWithPatterns(const Node* node, const SiteContainer& sequences, const TransitionModel& model) throw (Exception);
   
 };
 
