@@ -61,17 +61,16 @@ class NonHomogeneousTreeLikelihood :
 	public virtual TreeLikelihood
 {
 	public:
-#ifndef NO_VIRTUAL_COV
+
     NonHomogeneousTreeLikelihood* clone() const = 0;
-#endif
 
   public:
-    const SubstitutionModel* getSubstitutionModel(int nodeId, size_t siteIndex) const throw (NodeNotFoundException)
+    const TransitionModel* getSubstitutionModel(int nodeId, size_t siteIndex) const throw (NodeNotFoundException)
     {
       return getSubstitutionModelForNode(nodeId);
     }
 
-    SubstitutionModel* getSubstitutionModel(int nodeId, size_t siteIndex) throw (NodeNotFoundException)
+    TransitionModel* getSubstitutionModel(int nodeId, size_t siteIndex) throw (NodeNotFoundException)
     {
       return getSubstitutionModelForNode(nodeId);
     }
@@ -83,7 +82,7 @@ class NonHomogeneousTreeLikelihood :
      * @return A pointer toward the corresponding model.
      * @throw NodeNotFoundException This exception may be thrown if the node is not found (depending on the implementation).
      */
-    virtual const SubstitutionModel* getSubstitutionModelForNode(int nodeId) const throw (NodeNotFoundException) = 0;
+    virtual const TransitionModel* getSubstitutionModelForNode(int nodeId) const throw (NodeNotFoundException) = 0;
 
     /**
      * @brief Get the substitution model associated to a given node.
@@ -92,7 +91,7 @@ class NonHomogeneousTreeLikelihood :
      * @return A pointer toward the corresponding model.
      * @throw NodeNotFoundException This exception may be thrown if the node is not found (depending on the implementation).
      */
-    virtual SubstitutionModel* getSubstitutionModelForNode(int nodeId) throw (NodeNotFoundException) = 0;
+    virtual TransitionModel* getSubstitutionModelForNode(int nodeId) throw (NodeNotFoundException) = 0;
 
     /**
      * @return The set of substitution models associated to this instance.
