@@ -54,7 +54,7 @@ using namespace std;
 
 RHomogeneousTreeLikelihood::RHomogeneousTreeLikelihood(
   const Tree& tree,
-  SubstitutionModel* model,
+  TransitionModel* model,
   DiscreteDistribution* rDist,
   bool checkRooted,
   bool verbose,
@@ -72,7 +72,7 @@ throw (Exception) :
 RHomogeneousTreeLikelihood::RHomogeneousTreeLikelihood(
   const Tree& tree,
   const SiteContainer& data,
-  SubstitutionModel* model,
+  TransitionModel* model,
   DiscreteDistribution* rDist,
   bool checkRooted,
   bool verbose,
@@ -859,9 +859,8 @@ void RHomogeneousTreeLikelihood::computeSubtreeLikelihood(const Node* node)
           Vdouble* pxy__son_c_x = &(*pxy__son_c)[x];
           double likelihood = 0;
           for (size_t y = 0; y < nbStates_; y++)
-          {
             likelihood += (*pxy__son_c_x)[y] * (*_likelihoods_son_i_c)[y];
-          }
+          
           (*_likelihoods_node_i_c)[x] *= likelihood;
         }
       }
