@@ -163,13 +163,13 @@ ProbabilisticSubstitutionMapping* SubstitutionMappingTools::computeSubstitutionV
         const VVVdouble* likelihoodsFather_son = &drtl.getLikelihoodData()->getLikelihoodArray(father->getId(), currentSon->getId());
 
         // Now iterate over all site partitions:
-        auto_ptr<TreeLikelihood::ConstBranchModelIterator> mit(drtl.getNewBranchModelIterator(currentSon->getId()));
+        unique_ptr<TreeLikelihood::ConstBranchModelIterator> mit(drtl.getNewBranchModelIterator(currentSon->getId()));
         VVVdouble pxy;
         bool first;
         while (mit->hasNext())
         {
           TreeLikelihood::ConstBranchModelDescription* bmd = mit->next();
-          auto_ptr<TreeLikelihood::SiteIterator> sit(bmd->getNewSiteIterator());
+          unique_ptr<TreeLikelihood::SiteIterator> sit(bmd->getNewSiteIterator());
           first = true;
           while (sit->hasNext())
           {
@@ -207,13 +207,13 @@ ProbabilisticSubstitutionMapping* SubstitutionMappingTools::computeSubstitutionV
       const Node* currentSon = father->getFather();
       const VVVdouble* likelihoodsFather_son = &drtl.getLikelihoodData()->getLikelihoodArray(father->getId(), currentSon->getId());
       // Now iterate over all site partitions:
-      auto_ptr<TreeLikelihood::ConstBranchModelIterator> mit(drtl.getNewBranchModelIterator(father->getId()));
+      unique_ptr<TreeLikelihood::ConstBranchModelIterator> mit(drtl.getNewBranchModelIterator(father->getId()));
       VVVdouble pxy;
       bool first;
       while (mit->hasNext())
       {
         TreeLikelihood::ConstBranchModelDescription* bmd = mit->next();
-        auto_ptr<TreeLikelihood::SiteIterator> sit(bmd->getNewSiteIterator());
+        unique_ptr<TreeLikelihood::SiteIterator> sit(bmd->getNewSiteIterator());
         first = true;
         while (sit->hasNext())
         {
@@ -270,13 +270,13 @@ ProbabilisticSubstitutionMapping* SubstitutionMappingTools::computeSubstitutionV
 
     // Iterate over all site partitions:
     const VVVdouble* likelihoodsFather_node = &(drtl.getLikelihoodData()->getLikelihoodArray(father->getId(), currentNode->getId()));
-    auto_ptr<TreeLikelihood::ConstBranchModelIterator> mit(drtl.getNewBranchModelIterator(currentNode->getId()));
+    unique_ptr<TreeLikelihood::ConstBranchModelIterator> mit(drtl.getNewBranchModelIterator(currentNode->getId()));
     VVVdouble pxy;
     bool first;
     while (mit->hasNext())
     {
       TreeLikelihood::ConstBranchModelDescription* bmd = mit->next();
-      substitutionCount.setSubstitutionModel(bmd->getModel());
+      substitutionCount.setSubstitutionModel(bmd->getSubstitutionModel());
       // compute all nxy first:
       VVVVdouble nxy(nbClasses);
       for (size_t c = 0; c < nbClasses; ++c)
@@ -303,7 +303,7 @@ ProbabilisticSubstitutionMapping* SubstitutionMappingTools::computeSubstitutionV
       }
 
       // Now loop over sites:
-      auto_ptr<TreeLikelihood::SiteIterator> sit(bmd->getNewSiteIterator());
+      unique_ptr<TreeLikelihood::SiteIterator> sit(bmd->getNewSiteIterator());
       first = true;
       while (sit->hasNext())
       {
@@ -474,13 +474,13 @@ ProbabilisticSubstitutionMapping* SubstitutionMappingTools::computeSubstitutionV
         const VVVdouble* likelihoodsFather_son = &drtl.getLikelihoodData()->getLikelihoodArray(father->getId(), currentSon->getId());
 
         // Now iterate over all site partitions:
-        auto_ptr<TreeLikelihood::ConstBranchModelIterator> mit(drtl.getNewBranchModelIterator(currentSon->getId()));
+        unique_ptr<TreeLikelihood::ConstBranchModelIterator> mit(drtl.getNewBranchModelIterator(currentSon->getId()));
         VVVdouble pxy;
         bool first;
         while (mit->hasNext())
         {
           TreeLikelihood::ConstBranchModelDescription* bmd = mit->next();
-          auto_ptr<TreeLikelihood::SiteIterator> sit(bmd->getNewSiteIterator());
+          unique_ptr<TreeLikelihood::SiteIterator> sit(bmd->getNewSiteIterator());
           first = true;
           while (sit->hasNext())
           {
@@ -518,13 +518,13 @@ ProbabilisticSubstitutionMapping* SubstitutionMappingTools::computeSubstitutionV
       const Node* currentSon = father->getFather();
       const VVVdouble* likelihoodsFather_son = &drtl.getLikelihoodData()->getLikelihoodArray(father->getId(), currentSon->getId());
       // Now iterate over all site partitions:
-      auto_ptr<TreeLikelihood::ConstBranchModelIterator> mit(drtl.getNewBranchModelIterator(father->getId()));
+      unique_ptr<TreeLikelihood::ConstBranchModelIterator> mit(drtl.getNewBranchModelIterator(father->getId()));
       VVVdouble pxy;
       bool first;
       while (mit->hasNext())
       {
         TreeLikelihood::ConstBranchModelDescription* bmd = mit->next();
-        auto_ptr<TreeLikelihood::SiteIterator> sit(bmd->getNewSiteIterator());
+        unique_ptr<TreeLikelihood::SiteIterator> sit(bmd->getNewSiteIterator());
         first = true;
         while (sit->hasNext())
         {
@@ -581,13 +581,13 @@ ProbabilisticSubstitutionMapping* SubstitutionMappingTools::computeSubstitutionV
 
     // Iterate over all site partitions:
     const VVVdouble* likelihoodsFather_node = &(drtl.getLikelihoodData()->getLikelihoodArray(father->getId(), currentNode->getId()));
-    auto_ptr<TreeLikelihood::ConstBranchModelIterator> mit(drtl.getNewBranchModelIterator(currentNode->getId()));
+    unique_ptr<TreeLikelihood::ConstBranchModelIterator> mit(drtl.getNewBranchModelIterator(currentNode->getId()));
     VVVdouble pxy;
     bool first;
     while (mit->hasNext())
     {
       TreeLikelihood::ConstBranchModelDescription* bmd = mit->next();
-      substitutionCount.setSubstitutionModel(modelSet.getModelForNode(currentNode->getId()));
+      substitutionCount.setSubstitutionModel(modelSet.getSubstitutionModelForNode(currentNode->getId()));
 
       // compute all nxy first:
       VVVVdouble nxy(nbClasses);
@@ -615,7 +615,7 @@ ProbabilisticSubstitutionMapping* SubstitutionMappingTools::computeSubstitutionV
       }
 
       // Now loop over sites:
-      auto_ptr<TreeLikelihood::SiteIterator> sit(bmd->getNewSiteIterator());
+      unique_ptr<TreeLikelihood::SiteIterator> sit(bmd->getNewSiteIterator());
       first = true;
       while (sit->hasNext())
       {
@@ -763,13 +763,13 @@ ProbabilisticSubstitutionMapping* SubstitutionMappingTools::computeSubstitutionV
         const VVVdouble* likelihoodsFather_son = &drtl.getLikelihoodData()->getLikelihoodArray(father->getId(), currentSon->getId());
 
         // Now iterate over all site partitions:
-        auto_ptr<TreeLikelihood::ConstBranchModelIterator> mit(drtl.getNewBranchModelIterator(currentSon->getId()));
+        unique_ptr<TreeLikelihood::ConstBranchModelIterator> mit(drtl.getNewBranchModelIterator(currentSon->getId()));
         VVVdouble pxy;
         bool first;
         while (mit->hasNext())
         {
           TreeLikelihood::ConstBranchModelDescription* bmd = mit->next();
-          auto_ptr<TreeLikelihood::SiteIterator> sit(bmd->getNewSiteIterator());
+          unique_ptr<TreeLikelihood::SiteIterator> sit(bmd->getNewSiteIterator());
           first = true;
           while (sit->hasNext())
           {
@@ -807,13 +807,13 @@ ProbabilisticSubstitutionMapping* SubstitutionMappingTools::computeSubstitutionV
       const Node* currentSon = father->getFather();
       const VVVdouble* likelihoodsFather_son = &drtl.getLikelihoodData()->getLikelihoodArray(father->getId(), currentSon->getId());
       // Now iterate over all site partitions:
-      auto_ptr<TreeLikelihood::ConstBranchModelIterator> mit(drtl.getNewBranchModelIterator(father->getId()));
+      unique_ptr<TreeLikelihood::ConstBranchModelIterator> mit(drtl.getNewBranchModelIterator(father->getId()));
       VVVdouble pxy;
       bool first;
       while (mit->hasNext())
       {
         TreeLikelihood::ConstBranchModelDescription* bmd = mit->next();
-        auto_ptr<TreeLikelihood::SiteIterator> sit(bmd->getNewSiteIterator());
+        unique_ptr<TreeLikelihood::SiteIterator> sit(bmd->getNewSiteIterator());
         first = true;
         while (sit->hasNext())
         {
@@ -869,13 +869,13 @@ ProbabilisticSubstitutionMapping* SubstitutionMappingTools::computeSubstitutionV
 
     // Iterate over all site partitions:
     const VVVdouble* likelihoodsFather_node = &drtl.getLikelihoodData()->getLikelihoodArray(father->getId(), currentNode->getId());
-    auto_ptr<TreeLikelihood::ConstBranchModelIterator> mit(drtl.getNewBranchModelIterator(currentNode->getId()));
+    unique_ptr<TreeLikelihood::ConstBranchModelIterator> mit(drtl.getNewBranchModelIterator(currentNode->getId()));
     VVVdouble pxy;
     bool first;
     while (mit->hasNext())
     {
       TreeLikelihood::ConstBranchModelDescription* bmd = mit->next();
-      substitutionCount.setSubstitutionModel(bmd->getModel());
+      substitutionCount.setSubstitutionModel(bmd->getSubstitutionModel());
       // compute all nxy first:
       VVVVdouble nxy(nbClasses);
       for (size_t c = 0; c < nbClasses; ++c)
@@ -902,7 +902,7 @@ ProbabilisticSubstitutionMapping* SubstitutionMappingTools::computeSubstitutionV
       }
 
       // Now loop over sites:
-      auto_ptr<TreeLikelihood::SiteIterator> sit(bmd->getNewSiteIterator());
+      unique_ptr<TreeLikelihood::SiteIterator> sit(bmd->getNewSiteIterator());
       first = true;
       while (sit->hasNext())
       {
@@ -1049,11 +1049,11 @@ ProbabilisticSubstitutionMapping* SubstitutionMappingTools::computeSubstitutionV
     // Then, we deal with the node of interest.
     // ('y' is the state at 'node' and 'x' the state at 'father'.)
     // Iterate over all site partitions:
-    auto_ptr<TreeLikelihood::ConstBranchModelIterator> mit(drtl.getNewBranchModelIterator(currentNode->getId()));
+    unique_ptr<TreeLikelihood::ConstBranchModelIterator> mit(drtl.getNewBranchModelIterator(currentNode->getId()));
     while (mit->hasNext())
     {
       TreeLikelihood::ConstBranchModelDescription* bmd = mit->next();
-      substitutionCount.setSubstitutionModel(bmd->getModel());
+      substitutionCount.setSubstitutionModel(bmd->getSubstitutionModel());
       // compute all nxy first:
       VVVdouble nxyt(nbTypes);
       for (size_t t = 0; t < nbTypes; ++t)
@@ -1071,7 +1071,7 @@ ProbabilisticSubstitutionMapping* SubstitutionMappingTools::computeSubstitutionV
         delete nxy;
       }
       // Now loop over sites:
-      auto_ptr<TreeLikelihood::SiteIterator> sit(bmd->getNewSiteIterator());
+      unique_ptr<TreeLikelihood::SiteIterator> sit(bmd->getNewSiteIterator());
       while (sit->hasNext())
       {
         size_t i = sit->next();
@@ -1171,11 +1171,11 @@ ProbabilisticSubstitutionMapping* SubstitutionMappingTools::computeSubstitutionV
     VVVdouble probsFather = DRTreeLikelihoodTools::getPosteriorProbabilitiesForEachStateForEachRate(drtl, father->getId());
 
     // Iterate over all site partitions:
-    auto_ptr<TreeLikelihood::ConstBranchModelIterator> mit(drtl.getNewBranchModelIterator(currentNode->getId()));
+    unique_ptr<TreeLikelihood::ConstBranchModelIterator> mit(drtl.getNewBranchModelIterator(currentNode->getId()));
     while (mit->hasNext())
     {
       TreeLikelihood::ConstBranchModelDescription* bmd = mit->next();
-      substitutionCount.setSubstitutionModel(bmd->getModel());
+      substitutionCount.setSubstitutionModel(bmd->getSubstitutionModel());
       // compute all nxy first:
       VVVVdouble nxy(nbClasses);
       for (size_t c = 0; c < nbClasses; ++c)
@@ -1202,7 +1202,7 @@ ProbabilisticSubstitutionMapping* SubstitutionMappingTools::computeSubstitutionV
       }
 
       // Now loop over sites:
-      auto_ptr<TreeLikelihood::SiteIterator> sit(bmd->getNewSiteIterator());
+      unique_ptr<TreeLikelihood::SiteIterator> sit(bmd->getNewSiteIterator());
       while (sit->hasNext())
       {
         size_t i = sit->next();
@@ -1329,7 +1329,7 @@ throw (IOException)
 
 /**************************************************************************************************/
 
-vector<double> SubstitutionMappingTools::computeTotalSubstitutionVectorForSite(const SubstitutionMapping& smap, size_t siteIndex)
+vector<double> SubstitutionMappingTools::computeTotalSubstitutionVectorForSitePerBranch(const SubstitutionMapping& smap, size_t siteIndex)
 {
   size_t nbBranches = smap.getNumberOfBranches();
   size_t nbTypes    = smap.getNumberOfSubstitutionTypes();
@@ -1347,6 +1347,24 @@ vector<double> SubstitutionMappingTools::computeTotalSubstitutionVectorForSite(c
 
 /**************************************************************************************************/
 
+vector<double> SubstitutionMappingTools::computeTotalSubstitutionVectorForSitePerType(const SubstitutionMapping& smap, size_t siteIndex)
+{
+  size_t nbBranches = smap.getNumberOfBranches();
+  size_t nbTypes    = smap.getNumberOfSubstitutionTypes();
+  Vdouble v(nbTypes);
+  for (size_t t = 0; t < nbTypes; ++t)
+  {
+    v[t] = 0;
+    for (size_t l = 0; l < nbBranches; ++l)
+    {
+      v[t] += smap(l, siteIndex, t);
+    }
+  }
+  return v;
+}
+
+/**************************************************************************************************/
+
 double SubstitutionMappingTools::computeNormForSite(const SubstitutionMapping& smap, size_t siteIndex)
 {
   double sumSquare = 0;
@@ -1397,6 +1415,7 @@ vector<double> SubstitutionMappingTools::computeSumForSite(const SubstitutionMap
 }
 
 /**************************************************************************************************/
+
 vector< vector<double> > SubstitutionMappingTools::getCountsPerBranch(
   DRTreeLikelihood& drtl,
   const vector<int>& ids,
@@ -1407,9 +1426,9 @@ vector< vector<double> > SubstitutionMappingTools::getCountsPerBranch(
 {
   SubstitutionRegister* reg2 = reg.clone();
 
-  auto_ptr<SubstitutionCount> count(new UniformizationSubstitutionCount(model, reg2));
+  unique_ptr<SubstitutionCount> count(new UniformizationSubstitutionCount(model, reg2));
 
-  auto_ptr<ProbabilisticSubstitutionMapping> mapping(SubstitutionMappingTools::computeSubstitutionVectors(drtl, ids, *count, false));
+  unique_ptr<ProbabilisticSubstitutionMapping> mapping(SubstitutionMappingTools::computeSubstitutionVectors(drtl, ids, *count, false));
 
   vector< vector<double> > counts(ids.size());
   size_t nbSites = mapping->getNumberOfSites();
@@ -1427,7 +1446,7 @@ vector< vector<double> > SubstitutionMappingTools::getCountsPerBranch(
       for (size_t t = 0; t < nbTypes; ++t)
       {
         tmp[t] = (*mapping)(mapping->getNodeIndex(ids[k]), i, t);
-        error = isnan(tmp[t]);
+        error = std::isnan(tmp[t]);
         if (error)
           goto ERROR;
         s += tmp[t];
@@ -1489,9 +1508,9 @@ vector< vector<double> > SubstitutionMappingTools::getCountsPerBranch(
 {
   SubstitutionRegister* reg2 = reg.clone();
 
-  auto_ptr<SubstitutionCount> count(new UniformizationSubstitutionCount(modelSet.getModel(0), reg2));
+  unique_ptr<SubstitutionCount> count(new UniformizationSubstitutionCount(modelSet.getSubstitutionModel(0), reg2));
 
-  auto_ptr<ProbabilisticSubstitutionMapping> mapping(SubstitutionMappingTools::computeSubstitutionVectors(drtl, modelSet, ids, *count, false));
+  unique_ptr<ProbabilisticSubstitutionMapping> mapping(SubstitutionMappingTools::computeSubstitutionVectors(drtl, modelSet, ids, *count, false));
 
   vector< vector<double> > counts(ids.size());
   size_t nbSites = mapping->getNumberOfSites();
@@ -1509,7 +1528,7 @@ vector< vector<double> > SubstitutionMappingTools::getCountsPerBranch(
       for (size_t t = 0; t < nbTypes; ++t)
       {
         tmp[t] = (*mapping)(mapping->getNodeIndex(ids[k]), i, t);
-        error = isnan(tmp[t]);
+        error = std::isnan(tmp[t]);
         if (error)
           goto ERROR;
         s += tmp[t];
@@ -1576,6 +1595,10 @@ vector< vector<double> > SubstitutionMappingTools::getNormalizationsPerBranch(
   // compute the AlphabetIndex for each substitutionType
   vector<UserAlphabetIndex1 > usai(nbTypes, UserAlphabetIndex1(nullModel->getAlphabet()));
 
+  for (size_t nbt = 0; nbt < nbTypes; nbt++)
+    for (size_t i = 0; i < nbStates; i++)
+      usai[nbt].setIndex(supportedStates[i], 0);
+
   for (size_t i = 0; i < nbStates; i++)
   {
     for (size_t j = 0; j < nbStates; j++)
@@ -1589,6 +1612,10 @@ vector< vector<double> > SubstitutionMappingTools::getNormalizationsPerBranch(
     }
   }
 
+  const WordAlphabet* wAlp=dynamic_cast<const WordAlphabet*>(nullModel->getAlphabet());
+  
+  float sizeWord=float(wAlp?wAlp->getLength():1);
+  
   // compute the normalization for each substitutionType
   vector< vector<double> > rewards(ids.size());
 
@@ -1599,9 +1626,9 @@ vector< vector<double> > SubstitutionMappingTools::getNormalizationsPerBranch(
 
   for (size_t nbt = 0; nbt < nbTypes; nbt++)
   {
-    auto_ptr<Reward> reward(new DecompositionReward(nullModel, &usai[nbt]));
+    unique_ptr<Reward> reward(new DecompositionReward(nullModel, &usai[nbt]));
 
-    auto_ptr<ProbabilisticRewardMapping> mapping(RewardMappingTools::computeRewardVectors(drtl, ids, *reward, false));
+    unique_ptr<ProbabilisticRewardMapping> mapping(RewardMappingTools::computeRewardVectors(drtl, ids, *reward, false));
 
     for (size_t k = 0; k < ids.size(); ++k)
     {
@@ -1609,7 +1636,7 @@ vector< vector<double> > SubstitutionMappingTools::getNormalizationsPerBranch(
       for (size_t i = 0; i < nbSites; ++i)
       {
         double tmp = (*mapping)(k, i);
-        if (isnan(tmp))
+        if (std::isnan(tmp))
         {
           if (verbose)
             ApplicationTools::displayWarning("On branch " + TextTools::toString(ids[k]) + ", reward for type " + reg.getTypeName(nbt + 1) + " could not be computed.");
@@ -1618,10 +1645,10 @@ vector< vector<double> > SubstitutionMappingTools::getNormalizationsPerBranch(
         }
         s += tmp;
       }
-      rewards[k][nbt] = s;
+      rewards[k][nbt] = s*sizeWord;
     }
-    reward.release();
-    mapping.release();
+    reward.reset();
+    mapping.reset();
   }
   return rewards;
 }
@@ -1651,13 +1678,16 @@ vector< vector<double> > SubstitutionMappingTools::getNormalizationsPerBranch(
 
   vector<UserAlphabetIndex1 >  usai(nbTypes, UserAlphabetIndex1(nullModelSet->getAlphabet()));
 
+  const WordAlphabet* wAlp=dynamic_cast<const WordAlphabet*>(nullModelSet->getAlphabet());
+  float sizeWord=float(wAlp?wAlp->getLength():1);
+
   for (size_t nbm = 0; nbm < nbModels; nbm++)
   {
     vector<int> mids = VectorTools::vectorIntersection(ids, nullModelSet->getNodesWithModel(nbm));
     
     if (mids.size()>0)
     {
-      const SubstitutionModel* modn = nullModelSet->getModel(nbm);
+      const SubstitutionModel* modn = nullModelSet->getSubstitutionModel(nbm);
       vector<int> supportedStates = modn->getAlphabetStates();
 
       for (size_t nbt = 0; nbt < nbTypes; nbt++)
@@ -1679,9 +1709,9 @@ vector< vector<double> > SubstitutionMappingTools::getNormalizationsPerBranch(
 
       for (size_t nbt = 0; nbt < nbTypes; nbt++)
       {
-        auto_ptr<Reward> reward(new DecompositionReward(nullModelSet->getModel(nbm), &usai[nbt]));
+        unique_ptr<Reward> reward(new DecompositionReward(nullModelSet->getSubstitutionModel(nbm), &usai[nbt]));
         
-        auto_ptr<ProbabilisticRewardMapping> mapping(RewardMappingTools::computeRewardVectors(drtl, mids, *reward, false));
+        unique_ptr<ProbabilisticRewardMapping> mapping(RewardMappingTools::computeRewardVectors(drtl, mids, *reward, false));
         
         for (size_t k = 0; k < mids.size(); k++)
         {
@@ -1689,7 +1719,7 @@ vector< vector<double> > SubstitutionMappingTools::getNormalizationsPerBranch(
           for (size_t i = 0; i < nbSites; ++i)
           {
             double tmp = (*mapping)(mapping->getNodeIndex(mids[k]), i);
-            if (isnan(tmp))
+            if (std::isnan(tmp))
             {
               if (verbose)
                 ApplicationTools::displayWarning("On branch " + TextTools::toString(mids[k]) + ", reward for type " + reg.getTypeName(nbt + 1) + " could not be computed.");
@@ -1700,10 +1730,10 @@ vector< vector<double> > SubstitutionMappingTools::getNormalizationsPerBranch(
               s += tmp;
           }
           
-          rewards[VectorTools::which(ids, mids[k])][nbt] = s;
+          rewards[VectorTools::which(ids, mids[k])][nbt] = s * sizeWord;
         }
-        reward.release();
-        mapping.release();
+        reward.reset();
+        mapping.reset();
       }
     }
   }
@@ -1767,7 +1797,7 @@ vector< vector<double> > SubstitutionMappingTools::getNormalizedCountsPerBranch(
   vector< vector<double> > counts;
   vector< vector<double> > factors;
 
-  counts = getCountsPerBranch(drtl, ids, modelSet->getModel(0), reg, -1, verbose);
+  counts = getCountsPerBranch(drtl, ids, modelSet->getSubstitutionModel(0), reg, -1, verbose);
   factors = getNormalizationsPerBranch(drtl, ids, nullModelSet, reg, verbose);
 
   size_t nbTypes = counts[0].size();
@@ -1804,23 +1834,14 @@ vector< vector<double> > SubstitutionMappingTools::getRelativeCountsPerBranch(
   const vector<int>& ids,
   SubstitutionModel* model,
   const SubstitutionRegister& reg,
-  bool stationarity,
   double threshold)
 {
   vector< vector<double> > counts = getCountsPerBranch(drtl, ids, model, reg, threshold);
 
-  const CategorySubstitutionRegister* creg;
-  if (!stationarity)
-  {
-    try
-    {
-      creg = &dynamic_cast<const CategorySubstitutionRegister&>(reg);
-    }
-    catch (Exception& ex)
-    {
-      throw Exception("The stationarity option can only be used with a category substitution register.");
-    }
+  const CategorySubstitutionRegister* creg = dynamic_cast<const CategorySubstitutionRegister*>(&reg);
 
+  if ((creg!=NULL) && !creg->isStationary())
+  {
     size_t nbTypes = counts[0].size();
 
     for (size_t k = 0; k < ids.size(); ++k)
@@ -1859,8 +1880,8 @@ void SubstitutionMappingTools::outputTotalCountsPerBranchPerSite(
   SubstitutionModel* model,
   const SubstitutionRegister& reg)
 {
-  auto_ptr<SubstitutionCount> count(new UniformizationSubstitutionCount(model, reg.clone()));
-  auto_ptr<ProbabilisticSubstitutionMapping> smap(SubstitutionMappingTools::computeSubstitutionVectors(drtl, ids, *count, false));
+  unique_ptr<SubstitutionCount> count(new UniformizationSubstitutionCount(model, reg.clone()));
+  unique_ptr<ProbabilisticSubstitutionMapping> smap(SubstitutionMappingTools::computeSubstitutionVectors(drtl, ids, *count, false));
 
   ofstream file;
   file.open(filename.c_str());
@@ -1877,13 +1898,13 @@ void SubstitutionMappingTools::outputTotalCountsPerBranchPerSite(
   file << "sites";
   for (size_t i = 0; i < nbBr; ++i)
   {
-    file << "\t" << i;
+    file << "\t" << ids[i];
   }
   file << endl;
 
   for (size_t k = 0; k < nbSites; ++k)
   {
-    vector<double> countsf = SubstitutionMappingTools::computeTotalSubstitutionVectorForSite(*smap, k);
+    vector<double> countsf = SubstitutionMappingTools::computeTotalSubstitutionVectorForSitePerBranch(*smap, k);
     file << k;
     for (size_t i = 0; i < nbBr; ++i)
     {
@@ -1894,6 +1915,45 @@ void SubstitutionMappingTools::outputTotalCountsPerBranchPerSite(
   file.close();
 }
 
+/**************************************************************************************************/
+
+void SubstitutionMappingTools::outputTotalCountsPerTypePerSite(
+  string& filename,
+  DRTreeLikelihood& drtl,
+  const vector<int>& ids,
+  SubstitutionModel* model,
+  const SubstitutionRegister& reg)
+{
+  unique_ptr<SubstitutionCount> count(new UniformizationSubstitutionCount(model, reg.clone()));
+  unique_ptr<ProbabilisticSubstitutionMapping> smap(SubstitutionMappingTools::computeSubstitutionVectors(drtl, ids, *count, false));
+
+  ofstream file;
+  file.open(filename.c_str());
+
+  size_t nbSites = smap->getNumberOfSites();
+  size_t nbTypes = smap->getNumberOfSubstitutionTypes();
+
+  file << "sites";
+  for (size_t i = 0; i < nbTypes; ++i)
+  {
+    file << "\t" << reg.getTypeName(i + 1);
+  }
+  file << endl;
+
+  for (size_t k = 0; k < nbSites; ++k)
+  {
+    vector<double> countsf = SubstitutionMappingTools::computeTotalSubstitutionVectorForSitePerType(*smap, k);
+    file << k;
+    for (size_t i = 0; i < nbTypes; ++i)
+    {
+      file << "\t" << countsf[i];
+    }
+    file << endl;
+  }
+  file.close();
+}
+
+
 /**************************************************************************************************/
 
 void SubstitutionMappingTools::outputIndividualCountsPerBranchPerSite(
@@ -1903,8 +1963,8 @@ void SubstitutionMappingTools::outputIndividualCountsPerBranchPerSite(
   SubstitutionModel* model,
   const SubstitutionRegister& reg)
 {
-  auto_ptr<SubstitutionCount> count(new UniformizationSubstitutionCount(model, reg.clone()));
-  auto_ptr<ProbabilisticSubstitutionMapping> smap(SubstitutionMappingTools::computeSubstitutionVectors(drtl, ids, *count, false));
+  unique_ptr<SubstitutionCount> count(new UniformizationSubstitutionCount(model, reg.clone()));
+  unique_ptr<ProbabilisticSubstitutionMapping> smap(SubstitutionMappingTools::computeSubstitutionVectors(drtl, ids, *count, false));
 
   ofstream file;
 
@@ -1913,7 +1973,12 @@ void SubstitutionMappingTools::outputIndividualCountsPerBranchPerSite(
 
   for (size_t i = 0; i < reg.getNumberOfSubstitutionTypes(); ++i)
   {
-    string path = filenamePrefix + TextTools::toString(i + 1) + string(".count");
+    string name=reg.getTypeName(i+1);
+    if (name=="")
+      name=TextTools::toString(i + 1);
+
+    string path = filenamePrefix + name + string(".count");
+    
     ApplicationTools::displayResult(string("Output counts of type ") + TextTools::toString(i + 1) + string(" to file"), path);
     file.open(path.c_str());
 
