@@ -58,6 +58,7 @@ AbstractSubstitutionModel::AbstractSubstitutionModel(const Alphabet* alpha, Stat
   alphabet_(alpha),
   stateMap_(stateMap),
   size_(alpha->getSize()),
+  isScalable_(true),
   rate_(1),
   generator_(size_, size_),
   freq_(size_),
@@ -202,6 +203,8 @@ const Matrix<double>& AbstractSubstitutionModel::getPij_t(double t) const
   return pijt_;
 }
 
+/******************************************************************************/
+
 const Matrix<double>& AbstractSubstitutionModel::getdPij_dt(double t) const
 {
   if (isNonSingular_)
@@ -271,6 +274,8 @@ const Matrix<double>& AbstractSubstitutionModel::getdPij_dt(double t) const
   return dpijt_;
 }
 
+/******************************************************************************/
+
 const Matrix<double>& AbstractSubstitutionModel::getd2Pij_dt2(double t) const
 {
   if (isNonSingular_)
@@ -353,9 +358,10 @@ double AbstractSubstitutionModel::getInitValue(size_t i, int state) const throw
   if (state < 0 || !alphabet_->isIntInAlphabet(state))
     throw BadIntException(state, "AbstractSubstitutionModel::getInitValue. Character " + alphabet_->intToChar(state) + " is not allowed in model.");
   vector<int> states = alphabet_->getAlias(state);
+
   for (size_t j = 0; j < states.size(); j++)
   {
-    if (getAlphabetStateAsInt(i) == states[j])
+     if (getAlphabetStateAsInt(i) == states[j])
       return 1.;
   }
   return 0.;
@@ -406,8 +412,23 @@ double AbstractSubstitutionModel::getScale() const
 
 /******************************************************************************/
 
-void AbstractSubstitutionModel::setScale(double scale) {
-  MatrixTools::scale(generator_, scale);
+void AbstractSubstitutionModel::setScale(double scale)
+{
+  if (isScalable_)
+  {
+    MatrixTools::scale(generator_, scale);
+    eigenValues_ *= scale;
+    iEigenValues_ *= scale;
+  }
+}
+
+
+/******************************************************************************/
+
+void AbstractSubstitutionModel::normalize() 
+{
+  if (isScalable_)
+    setScale(1/getScale());
 }
 
 /******************************************************************************/
@@ -423,11 +444,11 @@ void AbstractSubstitutionModel::setRate(double rate)
 {
   if (rate <= 0)
     throw Exception("Bad value for rate: " + TextTools::toString(rate));
-
+  
   if (hasParameter("rate"))
-    setParameterValue("rate", rate_);
-
-  rate_ = rate;
+    setParameterValue("rate", rate);
+  else
+    rate_ = rate;
 }
 
 void AbstractSubstitutionModel::addRateParameter()
@@ -442,6 +463,7 @@ void AbstractReversibleSubstitutionModel::updateMatrices()
   RowMatrix<double> Pi;
   MatrixTools::diag(freq_, Pi);
   MatrixTools::mult(exchangeability_, Pi, generator_); // Diagonal elements of the exchangability matrix will be ignored.
+
   // Compute diagonal elements of the generator:
   for (size_t i = 0; i < size_; i++)
   {
@@ -453,17 +475,17 @@ void AbstractReversibleSubstitutionModel::updateMatrices()
     }
     generator_(i, i) = -lambda;
   }
+  
   // Normalization:
-  double scale = getScale();
-  MatrixTools::scale(generator_, 1. / scale);
-
-  // Normalize exchangeability matrix too:
-  MatrixTools::scale(exchangeability_, 1. / scale);
+  normalize();
+  
   // Compute diagonal elements of the exchangeability matrix:
   for (size_t i = 0; i < size_; i++)
-  {
-    exchangeability_(i, i) = generator_(i, i) / freq_[i];
-  }
+    for (size_t j = 0; j < size_; j++)
+    {
+      exchangeability_(i, j) = generator_(i, j) / freq_[i];
+    }
+  
   AbstractSubstitutionModel::updateMatrices();
 }
 
