@@ -88,13 +88,20 @@ protected:
   /**
    * @brief The map of model states with alphabet states.
    */
-  std::auto_ptr<StateMap> stateMap_;
+  std::unique_ptr<StateMap> stateMap_;
 
   /**
    * @brief The size of the generator, i.e. the number of states.
    */
   size_t size_;
 
+  /**
+   * @brief If the model is scalable (ie generator can be normalized
+   * automatically).
+   */
+  
+  bool isScalable_;
+
   /**
    * @brief The rate of the model (default: 1). The generator (and all
    * its vectorial components) is independent of the rate, since it
@@ -118,7 +125,6 @@ protected:
    * reversible, this matrix is symetric.
    *
    */
-  
   RowMatrix<double> exchangeability_;
 
   /**
@@ -146,7 +152,6 @@ protected:
   /**
    * @brief boolean value for diagonalizability in R of the generator_
    */
-  
   bool isDiagonalizable_;
 
   /**
@@ -184,6 +189,7 @@ public:
     alphabet_(model.alphabet_),
     stateMap_(model.stateMap_->clone()),
     size_(model.size_),
+    isScalable_(model.isScalable_),
     rate_(model.rate_),
     generator_(model.generator_),
     freq_(model.freq_),
@@ -208,6 +214,7 @@ public:
     alphabet_          = model.alphabet_;
     stateMap_.reset(model.stateMap_->clone());
     size_              = model.size_;
+    isScalable_        = model.isScalable_;
     rate_              = model.rate_;
     generator_         = model.generator_;
     freq_              = model.freq_;
@@ -229,9 +236,7 @@ public:
   
   virtual ~AbstractSubstitutionModel() {}
 
-#ifndef NO_VIRTUAL_COV
   virtual AbstractSubstitutionModel* clone() const = 0;
-#endif
 
 public:
   const Alphabet* getAlphabet() const { return alphabet_; }
@@ -298,10 +303,23 @@ public:
   virtual void fireParameterChanged(const ParameterList& parameters)
   {
     AbstractParameterAliasable::fireParameterChanged(parameters);
-    if ((parameters.size()!=1) || (parameters[0].getName()!=getNamespace()+"rate"))
-      updateMatrices();
+    
+    if (parameters.hasParameter(getNamespace()+"rate"))
+    {
+      rate_=parameters.getParameterValue(getNamespace()+"rate");
+      
+      if (parameters.size()!=1)
+        updateMatrices();
+    }
+    else
+      updateMatrices();      
   }
 
+  /**
+   * @brief add a "rate" parameter to the model, that handles the
+   * overall rate of the process.
+   *
+   */
   void addRateParameter();
 
 protected:
@@ -320,26 +338,61 @@ protected:
    * The optional rate parameter is not taken into account in this
    * method to prevent unnecessary computation.
    */
-  
   virtual void updateMatrices();
 
 public:
+
+  /**
+   * @brief sets if model is scalable, ie scale can be changed.
+   * Default : true, set to false to avoid normalization for example.
+   *
+   */
+  
+  void setScalable(bool scalable)
+  {
+    isScalable_=scalable;
+  }
+  
+  /**
+   * @brief returns  if model is scalable
+   *
+   */
+
+  virtual bool isScalable() const
+  {
+    return isScalable_;
+  }
+
+  /**
+   * @brief return scale
+   *
+   */
+  
   double getScale() const;
 
-  /*
+  /**
    * @brief Multiplies the current generator by the given scale.
    *
    * @param scale the scale by which the generator is multiplied.
    *
    */
-  
   void setScale(double scale);
 
+  /**
+   * @brief normalize the generator
+   *
+   */
+
+  virtual void normalize();
+  
+  /**
+   * @brief The rate of the substitution process.
+   *
+   */
   virtual double getRate() const;
 
   virtual void setRate(double rate);
 
-
   friend class AbstractBiblioSubstitutionModel;
 
 };
@@ -368,7 +421,6 @@ public:
  * characters in the alphabet. Consider using the
  * MarkovModulatedSubstitutionModel for more complexe cases.
  */
-  
 class AbstractReversibleSubstitutionModel :
   public AbstractSubstitutionModel,
   public virtual ReversibleSubstitutionModel
@@ -384,9 +436,7 @@ public:
 
   virtual ~AbstractReversibleSubstitutionModel() {}
 
-#ifndef NO_VIRTUAL_COV
   virtual AbstractReversibleSubstitutionModel* clone() const = 0;
-#endif
 
 protected:
 
