@@ -40,8 +40,6 @@
 #ifndef _CODONSUBSTITUTIONMODEL_H_
 #define _CODONSUBSTITUTIONMODEL_H_
 
-#include <Bpp/Numeric/ParameterAliasable.h>
-
 //From bpp-seq:
 #include <Bpp/Seq/GeneticCode/GeneticCode.h>
 
@@ -63,9 +61,7 @@ namespace bpp
     CodonSubstitutionModel() {}
     virtual ~CodonSubstitutionModel() {}
 
-#ifndef NO_VIRTUAL_COV
     virtual CodonSubstitutionModel* clone() const = 0;
-#endif
 
   public:
 
@@ -80,6 +76,22 @@ namespace bpp
     virtual double getCodonsMulRate(size_t, size_t) const = 0;
   };
   
+  
+  /**
+   * @brief Abstract class for reversible codon models
+   * @author Julien Dutheil
+   */
+  class CodonReversibleSubstitutionModel:
+    public virtual CodonSubstitutionModel,
+    public virtual ReversibleSubstitutionModel 
+  {
+  public:
+    CodonReversibleSubstitutionModel() {}
+    virtual ~CodonReversibleSubstitutionModel() {}
+
+    virtual CodonReversibleSubstitutionModel* clone() const = 0;
+  };
+
 } // end of namespace bpp.
 
 #endif
