@@ -87,11 +87,10 @@ namespace bpp
  */
 class YN98 :
     public AbstractBiblioSubstitutionModel,
-    public virtual CodonSubstitutionModel,
-    public virtual ReversibleSubstitutionModel
+    public virtual CodonReversibleSubstitutionModel
 {
 private:
-  std::auto_ptr<CodonDistanceFrequenciesSubstitutionModel> pmodel_;
+  std::unique_ptr<CodonDistanceFrequenciesSubstitutionModel> pmodel_;
 
 public:
   YN98(const GeneticCode* gc, FrequenciesSet* codonFreqs);
