@@ -150,6 +150,8 @@ void FullCodonFrequenciesSet::setFrequencies(const vector<double>& frequencies)
 
 void FullCodonFrequenciesSet::fireParameterChanged(const ParameterList& parameters)
 {
+  AbstractFrequenciesSet::fireParameterChanged(parameters);
+
   sFreq_.matchParametersValues(parameters);
   updateFreq_();
 }
@@ -248,6 +250,8 @@ FullPerAACodonFrequenciesSet& FullPerAACodonFrequenciesSet::operator=(const Full
 
 void FullPerAACodonFrequenciesSet::fireParameterChanged(const ParameterList& parameters)
 {
+  AbstractFrequenciesSet::fireParameterChanged(parameters);
+
   if (dynamic_cast<AbstractFrequenciesSet*>(ppfs_.get()))
     (dynamic_cast<AbstractFrequenciesSet*>(ppfs_.get()))->matchParametersValues(parameters);
   for (size_t i = 0; i < vS_.size(); i++)
@@ -266,7 +270,7 @@ void FullPerAACodonFrequenciesSet::updateFrequencies()
     std::vector<int> vc = pgc_->getSynonymous(aa);
     for (size_t j = 0; j < vc.size(); j++)
     {
-      //NB: only one alphabet state per model state here, as it is a CodonFreqSet.
+      // NB: only one alphabet state per model state here, as it is a CodonFreqSet.
       getFreq_(getStateMap().getModelStates(vc[j])[0]) =
         static_cast<double>(vc.size()) * ppfs_->getFrequencies()[i] * vS_[i].prob(j);
     }
@@ -281,7 +285,7 @@ void FullPerAACodonFrequenciesSet::setFrequencies(const vector<double>& frequenc
 
   double bigS = 0;
   Vdouble vaa;
-  
+
   const StateMap& aaStates = ppfs_->getStateMap();
   for (size_t i = 0; i < aaStates.getNumberOfModelStates(); ++i)
   {
@@ -289,14 +293,14 @@ void FullPerAACodonFrequenciesSet::setFrequencies(const vector<double>& frequenc
     std::vector<int> vc = pgc_->getSynonymous(aa);
     Vdouble vp;
     double s = 0;
-    
+
     for (size_t j = 0; j < vc.size(); j++)
     {
       size_t index = pgc_->getSourceAlphabet()->getStateIndex(vc[j]);
-      vp.push_back(frequencies[index-1]);
-      s += frequencies[index-1];
+      vp.push_back(frequencies[index - 1]);
+      s += frequencies[index - 1];
     }
-      
+
     vp /= s;
     vS_[i].setFrequencies(vp);
 
@@ -378,16 +382,16 @@ CodonFromIndependentFrequenciesSet::CodonFromIndependentFrequenciesSet(
   const GeneticCode* gCode,
   const std::vector<FrequenciesSet*>& freqvector,
   const string& name,
-  const string& mgmtStopFreq) :
+  const string& mgmtStopCodon) :
   WordFromIndependentFrequenciesSet(gCode->getSourceAlphabet(), freqvector, "", name),
   mStopNeigh_(),
-  mgmtStopFreq_(2),
+  mgmtStopCodon_(2),
   pgc_(gCode)
 {
-  if (mgmtStopFreq == "uniform")
-    mgmtStopFreq_ = 0;
-  else if (mgmtStopFreq == "linear")
-    mgmtStopFreq_ = 1;
+  if (mgmtStopCodon == "uniform")
+    mgmtStopCodon_ = 0;
+  else if (mgmtStopCodon == "linear")
+    mgmtStopCodon_ = 1;
 
   // fill the map of the stop codons
 
@@ -419,7 +423,7 @@ const CodonAlphabet* CodonFromIndependentFrequenciesSet::getAlphabet() const
 CodonFromIndependentFrequenciesSet::CodonFromIndependentFrequenciesSet(const CodonFromIndependentFrequenciesSet& iwfs) :
   WordFromIndependentFrequenciesSet(iwfs),
   mStopNeigh_(iwfs.mStopNeigh_),
-  mgmtStopFreq_(iwfs.mgmtStopFreq_),
+  mgmtStopCodon_(iwfs.mgmtStopCodon_),
   pgc_(iwfs.pgc_)
 {
   updateFrequencies();
@@ -429,7 +433,7 @@ CodonFromIndependentFrequenciesSet& CodonFromIndependentFrequenciesSet::operator
 {
   WordFromIndependentFrequenciesSet::operator=(iwfs);
   mStopNeigh_ = iwfs.mStopNeigh_;
-  mgmtStopFreq_ = iwfs.mgmtStopFreq_;
+  mgmtStopCodon_ = iwfs.mgmtStopCodon_;
   pgc_ = iwfs.pgc_;
   return *this;
 }
@@ -440,7 +444,7 @@ void CodonFromIndependentFrequenciesSet::updateFrequencies()
 
   size_t s = getAlphabet()->getSize();
 
-  if (mgmtStopFreq_ != 0)
+  if (mgmtStopCodon_ != 0)
   {
     // The frequencies of the stop codons are distributed to all
     // neighbour non-stop codons
@@ -458,12 +462,12 @@ void CodonFromIndependentFrequenciesSet::updateFrequencies()
       double sneifreq = 0;
       for (size_t vn = 0; vn < vneigh.size(); vn++)
       {
-        sneifreq += pow(getFreq_(static_cast<size_t>(vneigh[vn])), mgmtStopFreq_);
+        sneifreq += pow(getFreq_(static_cast<size_t>(vneigh[vn])), mgmtStopCodon_);
       }
       double x = getFreq_(static_cast<size_t>(stNb)) / sneifreq;
       for (size_t vn = 0; vn < vneigh.size(); vn++)
       {
-        f[vneigh[vn]] += pow(getFreq_(static_cast<size_t>(vneigh[vn])), mgmtStopFreq_) * x;
+        f[vneigh[vn]] += pow(getFreq_(static_cast<size_t>(vneigh[vn])), mgmtStopCodon_) * x;
       }
       getFreq_(static_cast<size_t>(stNb)) = 0;
       mStopNeigh_it++;
@@ -501,16 +505,16 @@ CodonFromUniqueFrequenciesSet::CodonFromUniqueFrequenciesSet(
   const GeneticCode* gCode,
   FrequenciesSet* pfreq,
   const string& name,
-  const string& mgmtStopFreq) :
+  const string& mgmtStopCodon) :
   WordFromUniqueFrequenciesSet(gCode->getSourceAlphabet(), pfreq, "", name),
   mStopNeigh_(),
-  mgmtStopFreq_(2),
+  mgmtStopCodon_(2),
   pgc_(gCode)
 {
-  if (mgmtStopFreq == "uniform")
-    mgmtStopFreq_ = 0;
-  else if (mgmtStopFreq == "linear")
-    mgmtStopFreq_ = 1;
+  if (mgmtStopCodon == "uniform")
+    mgmtStopCodon_ = 0;
+  else if (mgmtStopCodon == "linear")
+    mgmtStopCodon_ = 1;
 
   // fill the map of the stop codons
 
@@ -544,7 +548,7 @@ const CodonAlphabet* CodonFromUniqueFrequenciesSet::getAlphabet() const
 CodonFromUniqueFrequenciesSet::CodonFromUniqueFrequenciesSet(const CodonFromUniqueFrequenciesSet& iwfs) :
   WordFromUniqueFrequenciesSet(iwfs),
   mStopNeigh_(iwfs.mStopNeigh_),
-  mgmtStopFreq_(iwfs.mgmtStopFreq_),
+  mgmtStopCodon_(iwfs.mgmtStopCodon_),
   pgc_(iwfs.pgc_)
 {
   updateFrequencies();
@@ -554,7 +558,7 @@ CodonFromUniqueFrequenciesSet& CodonFromUniqueFrequenciesSet::operator=(const Co
 {
   WordFromUniqueFrequenciesSet::operator=(iwfs);
   mStopNeigh_ = iwfs.mStopNeigh_;
-  mgmtStopFreq_ = iwfs.mgmtStopFreq_;
+  mgmtStopCodon_ = iwfs.mgmtStopCodon_;
   pgc_ = iwfs.pgc_;
   return *this;
 }
@@ -565,39 +569,31 @@ void CodonFromUniqueFrequenciesSet::updateFrequencies()
 
   size_t s = getAlphabet()->getSize();
 
-  if (mgmtStopFreq_ != 0)
+  if (mgmtStopCodon_ != 0)
   {
     // The frequencies of the stop codons are distributed to all
     // neighbour non-stop codons
-    double f[64];
-    for (size_t i = 0; i < s; i++)
+    double f[64] = {0};
+    
+    for (auto mStopNeigh_it : mStopNeigh_)
     {
-      f[i] = 0;
-    }
-
-    std::map<int, Vint>::iterator mStopNeigh_it(mStopNeigh_.begin());
-    while (mStopNeigh_it != mStopNeigh_.end())
-    {
-      int stNb = mStopNeigh_it->first;
-      Vint vneigh = mStopNeigh_it->second;
+      int stNb = mStopNeigh_it.first;
+      Vint vneigh = mStopNeigh_it.second;
       double sneifreq = 0;
       for (size_t vn = 0; vn < vneigh.size(); vn++)
       {
-        sneifreq += pow(getFreq_(static_cast<size_t>(vneigh[vn])), mgmtStopFreq_);
+        sneifreq += pow(getFreq_(static_cast<size_t>(vneigh[vn])), mgmtStopCodon_);
       }
       double x = getFreq_(static_cast<size_t>(stNb)) / sneifreq;
       for (size_t vn = 0; vn < vneigh.size(); vn++)
       {
-        f[vneigh[vn]] += pow(getFreq_(static_cast<size_t>(vneigh[vn])), mgmtStopFreq_) * x;
+        f[vneigh[vn]] += pow(getFreq_(static_cast<size_t>(vneigh[vn])), mgmtStopCodon_) * x;
       }
       getFreq_(static_cast<size_t>(stNb)) = 0;
-      mStopNeigh_it++;
     }
 
     for (size_t i = 0; i < s; i++)
-    {
       getFreq_(i) += f[i];
-    }
   }
   else
   {
@@ -620,21 +616,21 @@ void CodonFromUniqueFrequenciesSet::updateFrequencies()
 
 /*********************************************************************/
 
-FrequenciesSet* CodonFrequenciesSet::getFrequenciesSetForCodons(short option, const GeneticCode* gCode, const string& mgmtStopFreq, unsigned short method)
+FrequenciesSet* CodonFrequenciesSet::getFrequenciesSetForCodons(short option, const GeneticCode* gCode, const string& mgmtStopCodon, unsigned short method)
 {
   FrequenciesSet* codonFreqs;
 
   if (option == F0)
     codonFreqs = new FixedCodonFrequenciesSet(gCode, "F0");
   else if (option == F1X4)
-    codonFreqs = new CodonFromUniqueFrequenciesSet(gCode, new FullNucleotideFrequenciesSet(gCode->getSourceAlphabet()->getNucleicAlphabet()), "F1X4", mgmtStopFreq);
+    codonFreqs = new CodonFromUniqueFrequenciesSet(gCode, new FullNucleotideFrequenciesSet(gCode->getSourceAlphabet()->getNucleicAlphabet()), "F1X4", mgmtStopCodon);
   else if (option == F3X4)
   {
     vector<FrequenciesSet*> v_AFS(3);
     v_AFS[0] = new FullNucleotideFrequenciesSet(gCode->getSourceAlphabet()->getNucleicAlphabet());
     v_AFS[1] = new FullNucleotideFrequenciesSet(gCode->getSourceAlphabet()->getNucleicAlphabet());
     v_AFS[2] = new FullNucleotideFrequenciesSet(gCode->getSourceAlphabet()->getNucleicAlphabet());
-    codonFreqs = new CodonFromIndependentFrequenciesSet(gCode, v_AFS, "F3X4", mgmtStopFreq);
+    codonFreqs = new CodonFromIndependentFrequenciesSet(gCode, v_AFS, "F3X4", mgmtStopCodon);
   }
   else if (option == F61)
     codonFreqs = new FullCodonFrequenciesSet(gCode, false, method, "F61");
