@@ -57,11 +57,10 @@ class CodonFrequenciesSet :
   public virtual FrequenciesSet
 {
 public:
-#ifndef NO_VIRTUAL_COV
+  
   CodonFrequenciesSet* clone() const = 0;
 
   const CodonAlphabet* getAlphabet() const = 0;
-#endif
 
 public:
   /**
@@ -75,7 +74,7 @@ public:
    *
    * @param option A code describing the option, one of F61, F1X4 or F3X4.
    * @param gCode The genetic code to use. The underlying codon alphabet object will be passed to the FrequenciesSet instance.
-   * @param mgmtStopFreq the optional way the frequencies assigned
+   * @param mgmtStopCodon the optional way the frequencies assigned
    * to the stop codons are redistributed to the other codons, with
    * F1X4 and F3X4 options. The available values are:
    *  - uniform : each stop frequency is distributed evenly
@@ -90,7 +89,7 @@ public:
    *
    * @see Simplex
    */
-  static FrequenciesSet* getFrequenciesSetForCodons(short option, const GeneticCode* gCode, const std::string& mgmtStopFreq = "quadratic", unsigned short method = 1);
+  static FrequenciesSet* getFrequenciesSetForCodons(short option, const GeneticCode* gCode, const std::string& mgmtStopCodon = "quadratic", unsigned short method = 1);
 
   static const short F0;
   static const short F1X4;
@@ -131,12 +130,7 @@ public:
   FullCodonFrequenciesSet(const FullCodonFrequenciesSet& fcfs);
   FullCodonFrequenciesSet& operator=(const FullCodonFrequenciesSet& fcfs);
 
-#ifndef NO_VIRTUAL_COV
-  FullCodonFrequenciesSet*
-#else
-  Clonable*
-#endif
-  clone() const { return new FullCodonFrequenciesSet(*this); }
+  FullCodonFrequenciesSet* clone() const { return new FullCodonFrequenciesSet(*this); }
 
 public:
   const GeneticCode* getGeneticCode() const { return pgc_; }
@@ -148,12 +142,10 @@ public:
    */
   void setFrequencies(const std::vector<double>& frequencies);
 
-#ifndef NO_VIRTUAL_COV
   const CodonAlphabet* getAlphabet() const
   {
     return dynamic_cast<const CodonAlphabet*>(AbstractFrequenciesSet::getAlphabet());
   }
-#endif
 
   void setNamespace(const std::string& nameSpace);
 
@@ -202,22 +194,16 @@ public:
     return *this;
   }
 
-#ifndef NO_VIRTUAL_COV
-  FixedCodonFrequenciesSet*
-#else
-  Clonable*
-#endif
-  clone() const { return new FixedCodonFrequenciesSet(*this); }
+  FixedCodonFrequenciesSet* clone() const { return new FixedCodonFrequenciesSet(*this); }
 
 public:
   const GeneticCode* getGeneticCode() const { return pgc_; }
 
-#ifndef NO_VIRTUAL_COV
   const CodonAlphabet* getAlphabet() const
   {
     return dynamic_cast<const CodonAlphabet*>(AbstractFrequenciesSet::getAlphabet());
   }
-#endif
+  
   /**
    * @brief the given frequencies are normalized such thaat the sum of
    * the frequencies on the non-stop codons equals 1.
@@ -242,20 +228,17 @@ protected:
  * @see Simplex
  *
  */
-
 class FullPerAACodonFrequenciesSet :
   public virtual CodonFrequenciesSet,
   public AbstractFrequenciesSet
 {
 private:
   const GeneticCode* pgc_;
-  std::auto_ptr<ProteinFrequenciesSet> ppfs_;
+  std::unique_ptr<ProteinFrequenciesSet> ppfs_;
 
-  /*
-     *@ brief vector of the simplexes, one for each AA
-   *
+  /**
+   * @ brief vector of the simplexes, one for each AA
    */
-
   std::vector<Simplex> vS_;
 
   void updateFrequencies();
@@ -287,20 +270,14 @@ public:
 
   virtual ~FullPerAACodonFrequenciesSet() {}
 
-#ifndef NO_VIRTUAL_COV
-  FullPerAACodonFrequenciesSet*
-#else
-  Clonable*
-#endif
-  clone() const { return new FullPerAACodonFrequenciesSet(*this); }
+  FullPerAACodonFrequenciesSet* clone() const { return new FullPerAACodonFrequenciesSet(*this); }
 
 public:
-#ifndef NO_VIRTUAL_COV
+  
   const CodonAlphabet* getAlphabet() const
   {
     return dynamic_cast<const CodonAlphabet*>(AbstractFrequenciesSet::getAlphabet());
   }
-#endif
 
   const GeneticCode* getGeneticCode() const { return pgc_; }
 
@@ -343,7 +320,7 @@ private:
   // a map associating stop codons numbers with numbers of neighbour non-stop codons
   std::map<int, Vint> mStopNeigh_;
 
-  unsigned short mgmtStopFreq_;
+  unsigned short mgmtStopCodon_;
 
   const GeneticCode* pgc_;
 
@@ -355,7 +332,7 @@ public:
    * @param gCode a pointer to the genetic code to use.
    * @param freqvector a vector of pointers to the phase specific FrequenciesSets
    * @param name the optional name of the FrequenciesSet (default codon)
-   * @param mgmtStopFreq the optional way the frequencies assigned to the
+   * @param mgmtStopCodon the optional way the frequencies assigned to the
    * stop codons are redistributed to the other codons. The
    * available values are:
    *  - uniform : each stop frequency is distributed evenly
@@ -367,7 +344,7 @@ public:
    *     the square of each target codon frequency.
    *
    */
-  CodonFromIndependentFrequenciesSet(const GeneticCode* gCode, const std::vector<FrequenciesSet*>& freqvector, const std::string& name = "Codon", const std::string& mgmtStopFreq = "quadratic");
+  CodonFromIndependentFrequenciesSet(const GeneticCode* gCode, const std::vector<FrequenciesSet*>& freqvector, const std::string& name = "Codon", const std::string& mgmtStopCodon = "quadratic");
 
   CodonFromIndependentFrequenciesSet(const CodonFromIndependentFrequenciesSet& iwfs);
 
@@ -382,9 +359,26 @@ public:
   const GeneticCode* getGeneticCode() const { return pgc_; }
 
   /**
-   * @ brief Update the frequencies given the parameters.
+   * @brief Update the frequencies given the parameters.
    */
   void updateFrequencies();
+
+  /**
+   * @brief Retrieve the mgmt method for the stop codons.
+   */
+  std::string getMgmtStopCodon() const
+  {
+    switch (mgmtStopCodon_)
+    {
+    case 0:
+      return "uniform";
+    case 1:
+      return "linear";
+    case 2:
+      return "quadratic";
+    }
+    return "";
+  }
 };
 
 
@@ -404,7 +398,7 @@ private:
   // a map associating stop codons numbers with numbers of neighbour non-stop codons
   std::map<int, Vint> mStopNeigh_;
 
-  unsigned short mgmtStopFreq_;
+  unsigned short mgmtStopCodon_;
 
   const GeneticCode* pgc_;
 
@@ -416,7 +410,7 @@ public:
    * @param gCode a pointer to a genetic code.
    * @param pfreq a pointer to the nucleotidic FrequenciesSet
    * @param name the optional name of the FrequenciesSet (default codon)
-   * @param mgmtStopFreq the optional way the frequencies assigned to the
+   * @param mgmtStopCodon the optional way the frequencies assigned to the
    * stop codons are redistributed to the other codons. The
    * available values are:
    *  - uniform : each stop frequency is distributed evenly
@@ -431,7 +425,7 @@ public:
     const GeneticCode* gCode,
     FrequenciesSet* pfreq,
     const std::string& name = "Codon",
-    const std::string& mgmtStopFreq = "quadratic");
+    const std::string& mgmtStopCodon = "quadratic");
 
   CodonFromUniqueFrequenciesSet(const CodonFromUniqueFrequenciesSet& iwfs);
 
@@ -450,6 +444,23 @@ public:
    *
    */
   void updateFrequencies();
+
+  /**
+   * @brief Retrieve the mgmt method for the stop codons.
+   */
+  std::string getMgmtStopCodon() const
+  {
+    switch (mgmtStopCodon_)
+    {
+    case 0:
+      return "uniform";
+    case 1:
+      return "linear";
+    case 2:
+      return "quadratic";
+    }
+    return "";
+  }
 };
 } // end of namespace bpp.
 
