@@ -177,12 +177,7 @@ namespace bpp
 
     virtual ~MarkovModulatedSubstitutionModel() { delete model_; }
 
-#ifndef NO_VIRTUAL_COV
-    MarkovModulatedSubstitutionModel*
-#else
-    Clonable*
-#endif
-    clone() const = 0;
+    MarkovModulatedSubstitutionModel* clone() const = 0;
 
   public:
 	  
@@ -237,7 +232,12 @@ namespace bpp
       updateMatrices();
     }
 
-
+    virtual void setFreq(std::map<int, double>& frequencies)
+    {
+      model_->setFreq(frequencies);
+      updateMatrices();
+    }
+    
     const ReversibleSubstitutionModel* getNestedModel() const { return model_; }
 
     /**
@@ -256,6 +256,22 @@ namespace bpp
 
     void setRate(double rate) { model_->setRate(rate); }
 
+    bool isScalable() const 
+    {
+      return model_->isScalable();
+    }
+
+    void setScalable(bool scalable)
+    {
+      model_->setScalable(scalable);
+    }
+
+    void normalize()
+    {
+      model_->normalize();
+      updateMatrices();
+    }
+    
     double getScale() const
     {
       std::vector<double> v;
