@@ -102,7 +102,7 @@ MixtureOfASubstitutionModel::MixtureOfASubstitutionModel(
   for (i = 0; i < c; i++)
   {
     modelsContainer_.push_back(model->clone());
-    modelsContainer_[i]->addRateParameter();
+//    modelsContainer_[i]->addRateParameter();
     modelsContainer_[i]->setNamespace(model->getNamespace());
 
     vProbas_.push_back(1.0 / static_cast<double>(c));
@@ -276,6 +276,17 @@ void MixtureOfASubstitutionModel::setFreq(std::map<int, double>& m)
   matchParametersValues(modelsContainer_[0]->getParameters());
 }
 
+const SubstitutionModel* MixtureOfASubstitutionModel::getSubModelWithName(const std::string& name) const
+{
+  size_t nbmod=getNumberOfModels();
+  
+  for (size_t i=0; i<nbmod; i++)
+    if (getNModel(i)->getName()==name)
+      return getNModel(i);
+
+  return NULL;
+}
+
 Vint MixtureOfASubstitutionModel::getSubmodelNumbers(string& desc) const
 {
   vector<string> parnames = modelsContainer_[0]->getParameters().getParameterNames();
