@@ -92,11 +92,6 @@ MixtureOfSubstitutionModels::MixtureOfSubstitutionModels(
     addParameters_(vpModel[i]->getParameters());
   }
 
-  for (i = 0; i < nbmod; i++)
-  {
-    vpModel[i]->addRateParameter();
-  }
-
   updateMatrices();
 }
 
@@ -178,11 +173,6 @@ MixtureOfSubstitutionModels::MixtureOfSubstitutionModels(
     addParameters_(vpModel[i]->getParameters());
   }
 
-  for (i = 0; i < nbmod; i++)
-  {
-    vpModel[i]->addRateParameter();
-  }
-
   updateMatrices();
 }
 
@@ -202,6 +192,16 @@ MixtureOfSubstitutionModels& MixtureOfSubstitutionModels::operator=(const Mixtur
 MixtureOfSubstitutionModels::~MixtureOfSubstitutionModels()
 {}
 
+const SubstitutionModel* MixtureOfSubstitutionModels::getSubModelWithName(const std::string& name) const
+{
+  size_t nbmod=getNumberOfModels();
+
+  for (size_t i=0; i<nbmod; i++)
+    if (getNModel(i)->getName()==name)
+      return getNModel(i);
+
+  return NULL;
+}
 
 void MixtureOfSubstitutionModels::updateMatrices()
 {
@@ -258,7 +258,7 @@ void MixtureOfSubstitutionModels::updateMatrices()
 
   for (i = 0; i < nbmod; i++)
   {
-    modelsContainer_[i]->setRate(vRates_[i]);
+    modelsContainer_[i]->setRate(rate_ * vRates_[i]);
     modelsContainer_[i]->matchParametersValues(getParameters());
   }
 
@@ -274,6 +274,7 @@ void MixtureOfSubstitutionModels::updateMatrices()
   }
 }
 
+
 void MixtureOfSubstitutionModels::setFreq(std::map<int, double>& m)
 {
   ParameterList pl;
