@@ -57,7 +57,7 @@ L95::L95(
 	const NucleicAlphabet* alphabet,
 	double alpha, double beta, double gamma, double kappa, double theta):
     AbstractParameterAliasable("L95."),
-    AbstractSubstitutionModel(alphabet, new CanonicalStateMap(alphabet, false), "L95."), alpha_(alpha), beta_(beta), gamma_(gamma), kappa_(kappa), theta_(theta)
+    AbstractNucleotideSubstitutionModel(alphabet, new CanonicalStateMap(alphabet, false), "L95."), alpha_(alpha), beta_(beta), gamma_(gamma), kappa_(kappa), theta_(theta)
 {
 
   addParameter_(new Parameter("L95.alpha", alpha, &Parameter::PROP_CONSTRAINT_IN));
@@ -102,7 +102,8 @@ void L95::updateMatrices()
   generator_(3,2) = kappa_* beta_ * theta_;
   generator_(3,3) = -kappa_ * theta_ - gamma_;
 
-  MatrixTools::scale(generator_, 1. / (2*kappa_*theta_*(1-theta_)+gamma_+theta_-2*theta_*gamma_));
+  setScale(1. / (2*kappa_*theta_*(1-theta_)+gamma_+theta_-2*theta_*gamma_));
+
   AbstractSubstitutionModel::updateMatrices();
 }
 
