@@ -58,7 +58,7 @@ RN95s::RN95s(const NucleicAlphabet* alphabet,
              double gamma,
              double delta) :
   AbstractParameterAliasable("RN95s."),
-  AbstractSubstitutionModel(alphabet, new CanonicalStateMap(alphabet, false), "RN95s."),
+  AbstractNucleotideSubstitutionModel(alphabet, new CanonicalStateMap(alphabet, false), "RN95s."),
   alpha_(),
   beta_(),
   gamma_(),
@@ -138,9 +138,9 @@ void RN95s::updateMatrices()
     x += generator_(i, i) * freq_[i];
   }
 
-  r_ = -1 / x;
-
-  MatrixTools::scale(generator_, r_);
+  r_ = isScalable()?-1 / x:1;
+  
+  setScale(r_);
 
   // variables for calculation purposes
 
