@@ -49,13 +49,13 @@ using namespace std;
 
 LGL08_CAT::LGL08_CAT(const ProteicAlphabet* alpha, unsigned int nbCat) :
   AbstractBiblioMixedSubstitutionModel("LGL08_CAT."),
-  pmixmodel_(0)
+  pmixmodel_()
 {
   // build the submodel
 
   vector<SubstitutionModel*> vpSM;
   for(unsigned int i = 1; i < nbCat + 1; i++)
-	vpSM.push_back(new LGL08_CAT::EmbeddedModel(alpha, "C" + TextTools::toString(i), nbCat));
+  vpSM.push_back(new LGL08_CAT::EmbeddedModel(alpha, "C" + TextTools::toString(i), nbCat));
 
   Vdouble vrate, vproba;
 
@@ -102,20 +102,20 @@ LGL08_CAT::~LGL08_CAT() {}
 
 LGL08_CAT::EmbeddedModel::EmbeddedModel(const ProteicAlphabet* alpha, string name, unsigned int nbCat) :
   AbstractParameterAliasable(name),
-  AbstractReversibleSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), name),
+  AbstractReversibleProteinSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), name),
   proportion_(1),
   name_(name)
 {
   //Exchangeabilities:
   for(unsigned int i = 0; i < 20; i++)
   {
-	for(unsigned int j = 0; j < 20; j++)
-	{
-	  if(i == j)
-		exchangeability_(i,i) = -19.;
-	  else
-		exchangeability_(i,j) = 1.;
-	}
+  for(unsigned int j = 0; j < 20; j++)
+  {
+    if(i == j)
+    exchangeability_(i,i) = -19.;
+    else
+    exchangeability_(i,j) = 1.;
+  }
   }
   
   //Equilibrium frequencies, rates and proportions:
@@ -127,30 +127,30 @@ LGL08_CAT::EmbeddedModel::EmbeddedModel(const ProteicAlphabet* alpha, string nam
   else if(nbCat == 20)
   {
 #include "__CATC20FrequenciesCode"
-#include "__CATC20RatesProps"	
+#include "__CATC20RatesProps"  
   }
   else if(nbCat == 30)
   {
 #include "__CATC30FrequenciesCode"
-#include "__CATC30RatesProps"	
+#include "__CATC30RatesProps"  
   }
   else if(nbCat == 40)
   {
 #include "__CATC40FrequenciesCode"
-#include "__CATC40RatesProps"	
+#include "__CATC40RatesProps"  
   }
   else if(nbCat == 50)
   {
 #include "__CATC50FrequenciesCode"
-#include "__CATC50RatesProps"	
+#include "__CATC50RatesProps"  
   }
   else if(nbCat == 60)
   {
 #include "__CATC60FrequenciesCode"
-#include "__CATC60RatesProps"	
+#include "__CATC60RatesProps"  
   }
   else
-	throw Exception("LGL08_CAT.cpp: incorrect number of profiles. This number has to be 10, 20, 30, 40, 50 or 60.");
+  throw Exception("LGL08_CAT.cpp: incorrect number of profiles. This number has to be 10, 20, 30, 40, 50 or 60.");
   
   updateMatrices();
 }
