@@ -49,7 +49,7 @@ using namespace std;
 
 LLG08_EHO::LLG08_EHO(const ProteicAlphabet* alpha) :
   AbstractBiblioMixedSubstitutionModel("LLG08_EHO."),
-  pmixmodel_(0)
+  pmixmodel_()
 {
   // build the submodel
 
@@ -102,7 +102,7 @@ LLG08_EHO::~LLG08_EHO() {}
 
 LLG08_EHO::EmbeddedModel::EmbeddedModel(const ProteicAlphabet* alpha, string name) :
   AbstractParameterAliasable(name),
-  AbstractReversibleSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), name),
+  AbstractReversibleProteinSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), name),
   proportion_(1),
   name_(name)
 {
