@@ -49,7 +49,7 @@ using namespace std;
 
 LLG08_UL3::LLG08_UL3(const ProteicAlphabet* alpha) :
   AbstractBiblioMixedSubstitutionModel("LLG08_UL3."),
-  pmixmodel_(0)
+  pmixmodel_()
 {
   // build the submodel
 
@@ -103,7 +103,7 @@ LLG08_UL3::~LLG08_UL3() {}
 
 LLG08_UL3::EmbeddedModel::EmbeddedModel(const ProteicAlphabet* alpha, string name) :
   AbstractParameterAliasable(name),
-  AbstractReversibleSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), name),
+  AbstractReversibleProteinSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), name),
   proportion_(1),
   name_(name)
 {
