@@ -60,7 +60,7 @@ SubstitutionModelSet::SubstitutionModelSet(const SubstitutionModelSet& set) :
   // Duplicate all model objects:
   for (size_t i = 0; i < set.modelSet_.size(); i++)
     {
-      modelSet_[i] = dynamic_cast<SubstitutionModel*>(set.modelSet_[i]->clone());
+      modelSet_[i] = dynamic_cast<TransitionModel*>(set.modelSet_[i]->clone());
     }
 }
 
@@ -82,7 +82,7 @@ SubstitutionModelSet& SubstitutionModelSet::operator=(const SubstitutionModelSet
   modelSet_.resize(set.modelSet_.size());
   for (size_t i = 0; i < set.modelSet_.size(); i++)
     {
-      modelSet_[i] = dynamic_cast<SubstitutionModel*>(set.modelSet_[i]->clone());
+      modelSet_[i] = dynamic_cast<TransitionModel*>(set.modelSet_[i]->clone());
     }
   return *this;
 }
@@ -125,14 +125,17 @@ std::vector<int> SubstitutionModelSet::getNodesWithParameter(const std::string&
   for (size_t i = 0; i < nalias.size(); i++)
     {
       p=nalias[i].rfind("_");
-      vector<int> ni = getNodesWithModel(TextTools::to<size_t>(nalias[i].substr(p+1,string::npos))-1);
-      inode.insert(inode.end(),ni.begin(),ni.end());
+      size_t pos=TextTools::to<size_t>(nalias[i].substr(p+1,string::npos));
+      if (pos>0){
+        vector<int> ni = getNodesWithModel(pos-1);
+        inode.insert(inode.end(),ni.begin(),ni.end());
+      }
     }
   
   return inode;
 }
 
-void SubstitutionModelSet::addModel(SubstitutionModel* model, const std::vector<int>& nodesId)//, const vector<string>& newParams) throw (Exception)
+void SubstitutionModelSet::addModel(TransitionModel* model, const std::vector<int>& nodesId)//, const vector<string>& newParams) throw (Exception)
 {
   if (model->getAlphabet()->getAlphabetType() != alphabet_->getAlphabetType())
     throw Exception("SubstitutionModelSet::addModel. A Substitution Model cannot be added to a Model Set if it does not have the same alphabet.");
@@ -166,12 +169,11 @@ void SubstitutionModelSet::addModel(SubstitutionModel* model, const std::vector<
     }
 }
 
-void SubstitutionModelSet::replaceModel(size_t modelIndex, SubstitutionModel* model) throw (Exception)
+void SubstitutionModelSet::replaceModel(size_t modelIndex, TransitionModel* model) throw (Exception)
 {
   delete modelSet_[modelIndex];
   modelSet_[modelIndex]=model;
   
-  
   // Erase all parameter references to this model
 
   ParameterList pl=getNodeParameters();
@@ -179,9 +181,10 @@ void SubstitutionModelSet::replaceModel(size_t modelIndex, SubstitutionModel* mo
   for (size_t i = pl.size(); i>0; i--)
     {
       string pn=pl[i-1].getName();
-
+      
       size_t pu=pn.rfind("_");
       int nm=TextTools::toInt(pn.substr(pu+1,string::npos));
+
       if (nm==(int)modelIndex+1){
         vector<string> alpn=getAlias(pn);
         for (unsigned j=0; j<alpn.size(); j++)
@@ -192,7 +195,7 @@ void SubstitutionModelSet::replaceModel(size_t modelIndex, SubstitutionModel* mo
             {
               continue;
             }
-        deleteParameter_(i-1);
+        deleteParameter_(pn);
       }
     }
 
@@ -302,7 +305,7 @@ bool SubstitutionModelSet::hasMixedSubstitutionModel() const
 {
   for (size_t i = 0; i < getNumberOfModels(); i++)
     {
-      if (dynamic_cast<const MixedSubstitutionModel*>(getModel(i)) != NULL)
+      if ((dynamic_cast<const MixedSubstitutionModel*>(getTransitionModel(i)) != NULL) && (modelToNodes_[i].size()>1))
         return true;
     }
   return false;
