@@ -166,7 +166,7 @@ throw (Exception)
   ParameterList pl = parameters;
 
   // Shall we reparametrize the function to remove constraints?
-  auto_ptr<DerivableSecondOrder> frep;
+  unique_ptr<DerivableSecondOrder> frep;
   if (reparametrization)
   {
     frep.reset(new ReparametrizationDerivableSecondOrderWrapper(f, parameters));
@@ -269,7 +269,7 @@ throw (Exception)
   DerivableSecondOrder* f = tl;
   ParameterList pl = parameters;
   // Shall we use a molecular clock constraint on branch lengths?
-  auto_ptr<GlobalClockTreeLikelihoodFunctionWrapper> fclock;
+  unique_ptr<GlobalClockTreeLikelihoodFunctionWrapper> fclock;
   if (useClock)
   {
     fclock.reset(new GlobalClockTreeLikelihoodFunctionWrapper(tl));
@@ -282,7 +282,7 @@ throw (Exception)
     pl.addParameters(fclock->getHeightParameters());
   }
   // Shall we reparametrize the function to remove constraints?
-  auto_ptr<DerivableSecondOrder> frep;
+  unique_ptr<DerivableSecondOrder> frep;
   if (reparametrization)
   {
     frep.reset(new ReparametrizationDerivableSecondOrderWrapper(f, pl));
@@ -292,9 +292,9 @@ throw (Exception)
     pl = f->getParameters().subList(pl.getParameterNames());
   }
 
-  auto_ptr<AbstractNumericalDerivative> fnum;
+  unique_ptr<AbstractNumericalDerivative> fnum;
   // Build optimizer:
-  auto_ptr<Optimizer> optimizer;
+  unique_ptr<Optimizer> optimizer;
   if (optMethodDeriv == OPTIMIZATION_GRADIENT)
   {
     fnum.reset(new TwoPointsNumericalDerivative(f));
@@ -665,7 +665,7 @@ DistanceMatrix* OptimizationTools::estimateDistanceMatrix(
   if (verbose > 0)
     ApplicationTools::displayTask("Estimating distance matrix", true);
   estimationMethod.computeMatrix();
-  auto_ptr<DistanceMatrix> matrix(estimationMethod.getMatrix());
+  unique_ptr<DistanceMatrix> matrix(estimationMethod.getMatrix());
   if (verbose > 0)
     ApplicationTools::displayTaskDone();
 
@@ -709,6 +709,18 @@ TreeTemplate<Node>* OptimizationTools::buildDistanceTree(
       ApplicationTools::displayTaskDone();
 
     // Compute tree:
+    if (matrix->size() == 2) {
+      //Special case, there is only one possible tree:
+      Node* n1 = new Node(0);
+      Node* n2 = new Node(1, matrix->getName(0));
+      n2->setDistanceToFather((*matrix)(0,0) / 2.);
+      Node* n3 = new Node(2, matrix->getName(1));
+      n3->setDistanceToFather((*matrix)(0,0) / 2.);
+      n1->addSon(n2);
+      n1->addSon(n3);
+      tree = new TreeTemplate<Node>(n1);
+      break;
+    }
     if (verbose > 0)
       ApplicationTools::displayTask("Building tree");
     reconstructionMethod.setDistanceMatrix(*matrix);
@@ -729,8 +741,8 @@ TreeTemplate<Node>* OptimizationTools::buildDistanceTree(
       break;  // Ends here.
 
     // Now, re-estimate parameters:
-    auto_ptr<SubstitutionModel> model(estimationMethod.getSubstitutionModel().clone());
-    auto_ptr<DiscreteDistribution> rdist(estimationMethod.getRateDistribution().clone());
+    unique_ptr<TransitionModel> model(estimationMethod.getSubstitutionModel().clone());
+    unique_ptr<DiscreteDistribution> rdist(estimationMethod.getRateDistribution().clone());
     DRHomogeneousTreeLikelihood tl(*tree,
         *estimationMethod.getData(),
         model.get(),
