@@ -70,7 +70,8 @@ NonHomogeneousSequenceSimulator::NonHomogeneousSequenceSimulator(
   nbNodes_(),
   nbClasses_(rate_->getNumberOfCategories()),
   nbStates_(modelSet_->getNumberOfStates()),
-  continuousRates_(false)
+  continuousRates_(false),
+  outputInternalSequences_(false)
 {
   if (!modelSet->isFullySetUpFor(*tree))
     throw Exception("NonHomogeneousSequenceSimulator(constructor). Model set is not fully specified.");
@@ -80,7 +81,7 @@ NonHomogeneousSequenceSimulator::NonHomogeneousSequenceSimulator(
 /******************************************************************************/
 
 NonHomogeneousSequenceSimulator::NonHomogeneousSequenceSimulator(
-  const SubstitutionModel* model,
+  const TransitionModel* model,
   const DiscreteDistribution* rate,
   const Tree* tree) :
   modelSet_(0),
@@ -95,11 +96,12 @@ NonHomogeneousSequenceSimulator::NonHomogeneousSequenceSimulator(
   nbNodes_(),
   nbClasses_(rate_->getNumberOfCategories()),
   nbStates_(model->getNumberOfStates()),
-  continuousRates_(false)
+  continuousRates_(false),
+  outputInternalSequences_(false)
 {
   FixedFrequenciesSet* fSet = new FixedFrequenciesSet(model->getStateMap().clone(), model->getFrequencies());
   fSet->setNamespace("anc.");
-  modelSet_ = SubstitutionModelSetTools::createHomogeneousModelSet(dynamic_cast<SubstitutionModel*>(model->clone()), fSet, templateTree_);
+  modelSet_ = SubstitutionModelSetTools::createHomogeneousModelSet(model->clone(), fSet, templateTree_);
   init();
 }
 
@@ -107,13 +109,28 @@ NonHomogeneousSequenceSimulator::NonHomogeneousSequenceSimulator(
 
 void NonHomogeneousSequenceSimulator::init()
 {
-  seqNames_.resize(leaves_.size());
-  for (size_t i = 0; i < seqNames_.size(); i++)
-  {
-    seqNames_[i] = leaves_[i]->getName();
+  vector<SNode*> nodes = tree_.getNodes();
+
+  if (outputInternalSequences_) {
+    seqNames_.resize(nodes.size());
+    for (size_t i = 0; i < seqNames_.size(); i++)
+    {
+      if (nodes[i]->isLeaf()) {
+        seqNames_[i] = nodes[i]->getName();
+      }
+    else {
+      seqNames_[i] = TextTools::toString( nodes[i]->getId() );
+      }
+    }
+  }
+  else {
+    seqNames_.resize(leaves_.size());
+    for (size_t i = 0; i < seqNames_.size(); i++)
+    {
+      seqNames_[i] = leaves_[i]->getName();
+    }
   }
   // Initialize cumulative pxy:
-  vector<SNode*> nodes = tree_.getNodes();
   nodes.pop_back(); // remove root
   nbNodes_ = nodes.size();
 
@@ -196,10 +213,29 @@ Site* NonHomogeneousSequenceSimulator::simulateSite(size_t ancestralStateIndex,
     evolveInternal(root->getSon(i), rateClass);
   }
   // Now create a Site object:
-  Vint site(leaves_.size());
-  for (size_t i = 0; i < leaves_.size(); ++i)
-  {
-    site[i] = leaves_[i]->getInfos().model->getAlphabetStateAsInt(leaves_[i]->getInfos().state);
+  size_t n = nbNodes_ + 1 ;
+  if (! outputInternalSequences_) {
+    n = leaves_.size() ;
+  }
+  Vint site(n);
+
+  if (outputInternalSequences_) {
+  vector<SNode*> nodes = tree_.getNodes();
+  for (size_t i = 0; i < n; i++)
+    {
+      if (i == n - 1) { // We take the model of node i-1 because the root has no model
+        site[i] = nodes[i-1]->getInfos().model->getAlphabetStateAsInt(nodes[i]->getInfos().state);
+      }
+      else {
+        site[i] = nodes[i]->getInfos().model->getAlphabetStateAsInt(nodes[i]->getInfos().state);
+      }
+    }
+  }
+  else {
+    for (size_t i = 0; i < leaves_.size(); ++i)
+    {
+      site[i] = leaves_[i]->getInfos().model->getAlphabetStateAsInt(leaves_[i]->getInfos().state);
+    }
   }
   return new Site(site, alphabet_);
 }
@@ -216,10 +252,29 @@ Site* NonHomogeneousSequenceSimulator::simulateSite(size_t ancestralStateIndex,
     evolveInternal(root->getSon(i), rate);
   }
   // Now create a Site object:
-  Vint site(leaves_.size());
-  for (size_t i = 0; i < leaves_.size(); i++)
-  {
-    site[i] = leaves_[i]->getInfos().model->getAlphabetStateAsInt(leaves_[i]->getInfos().state);
+  size_t n = nbNodes_ + 1 ;
+  if (! outputInternalSequences_) {
+    n = leaves_.size() ;
+  }
+  Vint site(n);
+
+  if (outputInternalSequences_) {
+  vector<SNode*> nodes = tree_.getNodes();
+  for (size_t i = 0; i < n; i++)
+    {
+      if (i == n - 1) { // We take the model of node i-1 because the root has no model
+        site[i] = nodes[i-1]->getInfos().model->getAlphabetStateAsInt(nodes[i]->getInfos().state);
+      }
+      else {
+        site[i] = nodes[i]->getInfos().model->getAlphabetStateAsInt(nodes[i]->getInfos().state);
+      }
+    }
+  }
+  else {
+    for (size_t i = 0; i < leaves_.size(); i++)
+    {
+      site[i] = leaves_[i]->getInfos().model->getAlphabetStateAsInt(leaves_[i]->getInfos().state);
+    }
   }
   return new Site(site, alphabet_);
 }
@@ -393,7 +448,7 @@ size_t NonHomogeneousSequenceSimulator::evolve(const SNode* node, size_t initial
   double cumpxy = 0;
   double rand = RandomTools::giveRandomNumberBetweenZeroAndEntry(1.);
   double l = rate * node->getDistanceToFather();
-  const SubstitutionModel* model = node->getInfos().model;
+  const TransitionModel* model = node->getInfos().model;
   for (size_t y = 0; y < nbStates_; y++)
   {
     cumpxy += model->Pij_t(initialStateIndex, y, l);
@@ -493,19 +548,44 @@ SiteContainer* NonHomogeneousSequenceSimulator::multipleEvolve(
   }
   // Now create a SiteContainer object:
   AlignedSequenceContainer* sites = new AlignedSequenceContainer(alphabet_);
-  size_t n = leaves_.size();
   size_t nbSites = initialStateIndices.size();
-  const SubstitutionModel* model = 0;
-  for (size_t i = 0; i < n; i++)
-  {
-    vector<int> content(nbSites);
-    vector<size_t>& states = leaves_[i]->getInfos().states;
-    model = leaves_[i]->getInfos().model;
-    for (size_t j = 0; j < nbSites; j++)
+  const TransitionModel* model = 0;
+  if (outputInternalSequences_) {
+    vector<SNode*> nodes = tree_.getNodes();
+    size_t n = nbNodes_ + 1 ;
+    for (size_t i = 0; i < n; i++)
     {
-      content[j] = model->getAlphabetStateAsInt(states[j]);
+      vector<int> content(nbSites);
+      vector<size_t>& states = nodes[i]->getInfos().states;
+      if (i == n - 1) { // If at the root, there is no model, so we take the model of node n-1.
+        model = nodes[i-1]->getInfos().model;
+      }
+      else {
+        model = nodes[i]->getInfos().model;
+      }
+      for (size_t j = 0; j < nbSites; j++)
+      {
+        content[j] = model->getAlphabetStateAsInt(states[j]);
+      }
+      if (nodes[i]->isLeaf())
+        sites->addSequence(BasicSequence(nodes[i]->getName(), content, alphabet_), false);
+      else
+        sites->addSequence(BasicSequence(TextTools::toString(nodes[i]->getId()), content, alphabet_), false);
+    }
+  }
+    else {
+    size_t n = leaves_.size();
+    for (size_t i = 0; i < n; i++)
+    {
+      vector<int> content(nbSites);
+      vector<size_t>& states = leaves_[i]->getInfos().states;
+      model = leaves_[i]->getInfos().model;
+      for (size_t j = 0; j < nbSites; j++)
+      {
+        content[j] = model->getAlphabetStateAsInt(states[j]);
+      }
+      sites->addSequence(BasicSequence(leaves_[i]->getName(), content, alphabet_), false);
     }
-    sites->addSequence(BasicSequence(leaves_[i]->getName(), content, alphabet_), false);
   }
   return sites;
 }
@@ -532,7 +612,12 @@ void NonHomogeneousSequenceSimulator::dEvolveInternal(SNode* node, double rate,
     cerr << "DEBUG: NonHomogeneousSequenceSimulator::evolveInternal. Forbidden call of method on root node." << endl;
     return;
   }
-  SimpleMutationProcess process(node->getInfos().model);
+  const TransitionModel* tm=node->getInfos().model;
+  if (dynamic_cast<const SubstitutionModel*>(tm)==0)
+    throw Exception("NonHomogeneousSequenceSimulator::dEvolveInternal : detailed simulation not possible for non-markovian model");
+  
+  SimpleMutationProcess process(dynamic_cast<const SubstitutionModel*>(tm));
+  
   MutationPath mp = process.detailedEvolve(node->getFather()->getInfos().state, node->getDistanceToFather() * rate);
   node->getInfos().state = mp.getFinalState();
 
@@ -548,3 +633,28 @@ void NonHomogeneousSequenceSimulator::dEvolveInternal(SNode* node, double rate,
 
 /******************************************************************************/
 
+void NonHomogeneousSequenceSimulator::outputInternalSequences(bool yn) {
+  outputInternalSequences_ = yn;
+  if (outputInternalSequences_) {
+    vector<SNode*> nodes = tree_.getNodes();
+    seqNames_.resize(nodes.size());
+    for (size_t i = 0; i < seqNames_.size(); i++)
+    {
+      if (nodes[i]->isLeaf()) {
+        seqNames_[i] = nodes[i]->getName();
+      }
+    else {
+      seqNames_[i] = TextTools::toString( nodes[i]->getId() );
+      }
+    }
+  }
+  else {
+    seqNames_.resize(leaves_.size());
+    for (size_t i = 0; i < seqNames_.size(); i++)
+    {
+      seqNames_[i] = leaves_[i]->getName();
+    }
+  }
+}
+
+/******************************************************************************/
