@@ -39,7 +39,7 @@
 
 #include "SequenceSimulationTools.h"
 
-// From SeqLib:
+// From bpp-seq:
 #include <Bpp/Seq/Container/VectorSiteContainer.h>
 
 using namespace bpp;
@@ -51,8 +51,8 @@ SiteContainer* SequenceSimulationTools::simulateSites(const SiteSimulator& simul
   vector<const Site*> vs(numberOfSites);
   for (size_t i = 0; i < numberOfSites; i++)
   {
-    Site* s = simulator.simulate(rates[i]);
-    s->setPosition((int)i);
+    Site* s = simulator.simulateSite(rates[i]);
+    s->setPosition(static_cast<int>(i));
     vs[i] = s;
   }
   SiteContainer* sites = new VectorSiteContainer(vs, simulator.getAlphabet());
@@ -66,7 +66,7 @@ SiteContainer* SequenceSimulationTools::simulateSites(const SiteSimulator& simul
   return sites;
 }
 
-SiteContainer* SequenceSimulationTools::simulateSites(const SiteSimulator& simulator, const vector<double>& rates, const vector<int>& states)
+SiteContainer* SequenceSimulationTools::simulateSites(const SiteSimulator& simulator, const vector<double>& rates, const vector<size_t>& states)
 throw (Exception)
 {
   size_t numberOfSites = rates.size();
@@ -75,8 +75,30 @@ throw (Exception)
   vector<const Site*> vs(numberOfSites);
   for (size_t i = 0; i < numberOfSites; i++)
   {
-    Site* s = simulator.simulate(states[i], rates[i]);
-    s->setPosition((int)i);
+    Site* s = simulator.simulateSite(states[i], rates[i]);
+    s->setPosition(static_cast<int>(i));
+    vs[i] = s;
+  }
+  SiteContainer* sites = new VectorSiteContainer(vs, simulator.getAlphabet());
+  sites->setSequencesNames(simulator.getSequencesNames(), false);
+  // Freeing memory:
+  for (size_t i = 0; i < numberOfSites; i++)
+  {
+    delete vs[i];
+  }
+
+  return sites;
+}
+
+SiteContainer* SequenceSimulationTools::simulateSites(const SiteSimulator& simulator, const vector<size_t>& states)
+throw (Exception)
+{
+  size_t numberOfSites = states.size();
+  vector<const Site*> vs(numberOfSites);
+  for (size_t i = 0; i < numberOfSites; i++)
+  {
+    Site* s = simulator.simulateSite(states[i]);
+    s->setPosition(static_cast<int>(i));
     vs[i] = s;
   }
   SiteContainer* sites = new VectorSiteContainer(vs, simulator.getAlphabet());
