@@ -165,6 +165,8 @@ public:
 
   size_t getNumberOfNodes() const { return TreeTemplateTools::getNumberOfNodes(*root_); }
 
+  size_t getNumberOfBranches() const { return getNumberOfNodes() -1;}
+
   int getLeafId(const std::string& name) const throw (NodeNotFoundException) { return TreeTemplateTools::getLeafId(*root_, name); }
 
   std::vector<int> getLeavesId() const { return TreeTemplateTools::getLeavesId(*root_); }
@@ -398,7 +400,7 @@ public:
    *
    * @{
    */
-  virtual void setRootNode(N* root) { root_ = root; }
+  virtual void setRootNode(N* root) { root_ = root; root_->removeFather(); }
 
   virtual N* getRootNode() { return root_; }
 
@@ -473,19 +475,13 @@ public:
     if (root_ == newRoot) return;
     if (isRooted()) unroot();
     std::vector<Node*> path = TreeTemplateTools::getPathBetweenAnyTwoNodes(*root_, *newRoot);
-
     for (size_t i = 0; i < path.size() - 1; i++)
     {
-      // pathMatrix[i] -> _father = pathMatrix[i + 1];
-      // pathMatrix[i] -> setDistanceToFather(pathMatrix[i + 1] -> getDistanceToFather());
-      // typename vector<Node *>::iterator vec_iter;
-      // vec_iter = remove(pathMatrix[i] -> _sons.begin(), pathMatrix[i] -> _sons.end(), pathMatrix[i + 1]);
-      // pathMatrix[i] -> _sons.erase(vec_iter, pathMatrix[i] -> _sons.end()); // pg 1170, primer.
-      // pathMatrix[i+1] -> _sons.push_back(pathMatrix[i + 1] -> getFather());
-      // pathMatrix[i+1] -> _father = 0;
-      path[i]->removeSon(path[i + 1]);
-      if (path[i + 1]->hasDistanceToFather()) path[i]->setDistanceToFather(path[i + 1]->getDistanceToFather());
+      if (path[i + 1]->hasDistanceToFather())  { 
+	      path[i]->setDistanceToFather(path[i + 1]->getDistanceToFather());
+	    }
       else path[i]->deleteDistanceToFather();
+      path[i]->removeSon(path[i + 1]);
       path[i + 1]->addSon(path[i]);
 
       std::vector<std::string> names = path[i + 1]->getBranchPropertyNames();
@@ -495,6 +491,7 @@ public:
       }
       path[i + 1]->deleteBranchProperties();
     }
+
     newRoot->deleteDistanceToFather();
     newRoot->deleteBranchProperties();
     root_ = newRoot;
