@@ -251,7 +251,7 @@ TreeTemplateTools::Element TreeTemplateTools::getElement(const string& elt) thro
 /******************************************************************************/
 
 
-Node* TreeTemplateTools::parenthesisToNode(const string& description, bool bootstrap, const string& propertyName, bool withId)
+Node* TreeTemplateTools::parenthesisToNode(const string& description, unsigned int& nodeCounter, bool bootstrap, const string& propertyName, bool withId, bool verbose)
 {
   // cout << "NODE: " << description << endl;
   Element elt = getElement(description);
@@ -320,28 +320,36 @@ Node* TreeTemplateTools::parenthesisToNode(const string& description, bool boots
     for (size_t i = 0; i < elements.size(); i++)
     {
       // cout << "NODE: SUBNODE: " << i << ", " << elements[i] << endl;
-      Node* son = parenthesisToNode(elements[i], bootstrap, propertyName, withId);
+      Node* son = parenthesisToNode(elements[i], nodeCounter, bootstrap, propertyName, withId, verbose);
       node->addSon(son);
     }
   }
+  nodeCounter++;
+  if (verbose)
+    ApplicationTools::displayUnlimitedGauge(nodeCounter);
   return node;
 }
 
 /******************************************************************************/
 
-TreeTemplate<Node>* TreeTemplateTools::parenthesisToTree(const string& description, bool bootstrap, const string& propertyName, bool withId) throw (Exception)
+TreeTemplate<Node>* TreeTemplateTools::parenthesisToTree(const string& description, bool bootstrap, const string& propertyName, bool withId, bool verbose) throw (Exception)
 {
   string::size_type semi = description.rfind(';');
   if (semi == string::npos)
     throw Exception("TreeTemplateTools::parenthesisToTree(). Bad format: no semi-colon found.");
   string content = description.substr(0, semi);
-  Node* node = parenthesisToNode(content, bootstrap, propertyName, withId);
+  unsigned int nodeCounter = 0;
+  Node* node = parenthesisToNode(content, nodeCounter, bootstrap, propertyName, withId, verbose);
   TreeTemplate<Node>* tree = new TreeTemplate<Node>();
   tree->setRootNode(node);
   if (!withId)
   {
     tree->resetNodesId();
   }
+  if (verbose) {
+    (*ApplicationTools::message) << " nodes loaded.";
+    ApplicationTools::message->endLine();
+  }
   return tree;
 }
 
@@ -618,7 +626,7 @@ TreeTemplate<Node>* TreeTemplateTools::getRandomTree(vector<string>& leavesNames
 
 /******************************************************************************/
 
-vector<Node*> TreeTemplateTools::getPathBetweenAnyTwoNodes(Node& node1, Node& node2, bool includeAncestor)
+vector<Node*> TreeTemplateTools::getPathBetweenAnyTwoNodes(Node& node1, Node& node2, bool includeAncestor, bool includeAncestorAtEndOfPath)
 {
   vector<Node*> path;
   vector<Node*> pathMatrix1;
@@ -652,11 +660,11 @@ vector<Node*> TreeTemplateTools::getPathBetweenAnyTwoNodes(Node& node1, Node& no
   } else if (pos1 == 0) {
     //Node 1 is the root node
     //Note: we need to use push_back here as the insert method does not work with reverse iterators.
-    for (size_t i = pathMatrix2.size(); i > 0; --i)
+    for (size_t i = (includeAncestorAtEndOfPath ? pathMatrix2.size(): pathMatrix2.size() - 1); i > 0; --i)
       path.push_back(pathMatrix2[i-1]);
   } else if (pos2 == 0) {
     //Node 2 is the root node
-    path.insert(path.end(), pathMatrix1.begin(), pathMatrix1.end());
+    path.insert(path.end(), pathMatrix1.begin(), (includeAncestorAtEndOfPath ? pathMatrix1.end() : --pathMatrix1.end()));
   } else {
     Node* commonAnc = 0;
     while (pathMatrix1[pos1] == pathMatrix2[pos2] && pos1 > 0 && pos2 > 0)
@@ -668,8 +676,8 @@ vector<Node*> TreeTemplateTools::getPathBetweenAnyTwoNodes(Node& node1, Node& no
     path.insert(path.end(), pathMatrix1.begin(), pathMatrix1.begin() + static_cast<ptrdiff_t>(pos1 + 1));
     if (includeAncestor && commonAnc)
       path.push_back(commonAnc); // pushing once the Node that was common to both.
-                                 // note: if node1 or node2 is the common ancestor, then commonAnc is null
-                                 // and will be added as node1 or node2, respectively, even if includeAncestor is false.
+    // If node1 or node2 is the common ancestor, then commonAnc is null
+    // and was added as node1 or node2, respectively, if includeAncestorAtEndOfPath was set to true.
     //Note: we need to use push_back here as the insert method does not work with reverse iterators.
     for (size_t i = pos2 + 1; i > 0; --i)
       path.push_back(pathMatrix2[i-1]);
@@ -679,7 +687,7 @@ vector<Node*> TreeTemplateTools::getPathBetweenAnyTwoNodes(Node& node1, Node& no
 
 /******************************************************************************/
 
-vector<const Node*> TreeTemplateTools::getPathBetweenAnyTwoNodes(const Node& node1, const Node& node2, bool includeAncestor)
+vector<const Node*> TreeTemplateTools::getPathBetweenAnyTwoNodes(const Node& node1, const Node& node2, bool includeAncestor, bool includeAncestorAtEndOfPath)
 {
   vector<const Node*> path;
   vector<const Node*> pathMatrix1;
@@ -713,11 +721,11 @@ vector<const Node*> TreeTemplateTools::getPathBetweenAnyTwoNodes(const Node& nod
   } else if (pos1 == 0) {
     //Node 1 is the root node
     //Note: we need to use push_back here as the insert method does not work with reverse iterators.
-    for (size_t i = pathMatrix2.size(); i > 0; --i)
+    for (size_t i = (includeAncestorAtEndOfPath ? pathMatrix2.size(): pathMatrix2.size() - 1); i > 0; --i)
       path.push_back(pathMatrix2[i-1]);
   } else if (pos2 == 0) {
     //Node 2 is the root node
-    path.insert(path.end(), pathMatrix1.begin(), pathMatrix1.end());
+    path.insert(path.end(), pathMatrix1.begin(), (includeAncestorAtEndOfPath ? pathMatrix1.end() : --pathMatrix1.end()));
   } else {
     const Node* commonAnc = 0;
     while (pathMatrix1[pos1] == pathMatrix2[pos2] && pos1 > 0 && pos2 > 0)
@@ -727,10 +735,11 @@ vector<const Node*> TreeTemplateTools::getPathBetweenAnyTwoNodes(const Node& nod
     }
 
     path.insert(path.end(), pathMatrix1.begin(), pathMatrix1.begin() + static_cast<ptrdiff_t>(pos1 + 1));
-    if (includeAncestor && commonAnc)
-      path.push_back(commonAnc); // pushing once the Node that was common to both.
-                                 // note: if node1 or node2 is the common ancestor, then commonAnc is null
-                                 // and will be added as node1 or node2, respectively, even if includeAncestor is false.
+    if (commonAnc &&includeAncestor)
+        path.push_back(commonAnc); // pushing once the Node that was common to both.
+    // If node1 or node2 is the common ancestor, then commonAnc is null
+    // and was added as node1 or node2, respectively, if includeAncestorAtEndOfPath was set to true.
+    
     //Note: we need to use push_back here as the insert method does not work with reverse iterators.
     for (size_t i = pos2 + 1; i > 0; --i)
       path.push_back(pathMatrix2[i-1]);
@@ -742,7 +751,7 @@ vector<const Node*> TreeTemplateTools::getPathBetweenAnyTwoNodes(const Node& nod
 
 double TreeTemplateTools::getDistanceBetweenAnyTwoNodes(const Node& node1, const Node& node2)
 {
-  vector<const Node*> path = getPathBetweenAnyTwoNodes(node1, node2, false);
+  vector<const Node*> path = getPathBetweenAnyTwoNodes(node1, node2, false, false);
   double d = 0;
   for (size_t i = 0; i < path.size(); ++i)
   {
